__all__ = (
    'Environs',
    'PathLike',
    'ObjDictA',
    'ObjDictB',
    'ObjDictC',
    'ObjDataA',
    'ObjDataB',
    'ObjDataC',

)
from collections import OrderedDict
from dataclasses import dataclass
from dataclasses import field
from logging import getLogger
from logging import Logger
from pathlib import Path as PathLike
from typing import Any
from typing import NamedTuple

from environs import Env as Environs

Named = NamedTuple('Named', a=Any)
logger = getLogger(__name__)


class ObjDictA:
    _a = 'a'
    clsvar = 3
    logger = logger

    __ignore_attr__ = ['b', ]
    __ignore_copy__ = [OrderedDict, ]

    def __init__(self):
        super(ObjDictA, self).__init__()
        # self.env = Environs()
        self._b = 2
        self._d = 4

    @property
    def a(self):
        return self._a

    @property
    def b(self):
        return 'b'


class ObjDictB:
    _b = 'b'
    dict_a = ObjDictA()
    env = Environs()
    path = PathLike()


class ObjDictC:
    _a = 'a'
    clsvar = None
    f = None
    logger = getLogger()

    __ignore_attr__ = ['b', ]
    __ignore_copy__ = [OrderedDict, ]

    def __init__(self):
        super(ObjDictC, self).__init__()  # self.env = Environs()
        self._b = [None, None]
        self._d = {None, self.f}
        self._e = OrderedDict()
        self.f = 2

    @property
    def a(self):
        return self._a

    @property
    def b(self):
        return 'b'


@dataclass
class ObjDataA:
    a: str = 'a'
    dict_a: ObjDictA = ObjDictA()
    dictionary: dict = field(default_factory=dict)
    env: Environs = Environs()
    integer: int = field(default=int(), init=False)
    logger: Logger = logger
    path: PathLike = PathLike()


def factory():
    return [logger, ObjDataA(), PathLike(), Environs()]


@dataclass
class ObjDataB:
    b: str = 'b'
    data_a: ObjDataA = ObjDataA()
    dict_a: ObjDictA = ObjDictA()
    dictionary: dict = field(default_factory=dict)
    env: Environs = field(default_factory=Environs)
    integer: int = field(default=int(), init=False)
    logger: Logger = logger
    lst: list = field(default_factory=factory)
    named: Named = Named(ObjDataA)
    named_data_a: Named = Named(ObjDataA())
    path: PathLike = PathLike()

    def __post_init__(self):
        self.env.read_env()


@dataclass
class ObjDataC:
    _cprop: str = 'cprop'
    data_b: ObjDataB = ObjDataB()
    dict_a: ObjDictA = ObjDictA()
    dictionary: dict = field(default_factory=dict)
    env: Environs = field(default_factory=Environs)
    integer: int = field(default=int(), init=False)
    logger: Logger = logger
    path: PathLike = PathLike()

    __ignore_kwarg__ = ['path', ]

    def __post_init__(self):
        self.dictionary = dict(a=dict(__a='_a', _a='__a', a='__a'))

    @property
    def cprop(self):
        return self._cprop




# coding=utf-8
import asyncio
from asyncio import as_completed
from asyncio import create_task
from asyncio import to_thread

from rclib import *


@funcdispatch
def sync():
    return True


@sync.register
async def _():
    return await to_thread(sync)


@funcdispatch
def func():
    return True


@func.register
async def _():
    return False


@funcdispatch
def func1(arg):
    return True, arg


@func1.register
async def _(arg):
    return False, arg


def funcdispatch_sync():
    return func()


async def funcdispatch_async():
    return await func()

module_sync_no_thread = sync()
module_sync_to_thread = asyncio.run(sync(), debug=False)
module_sync = func()
module_async = asyncio.run(func(), debug=False)
function_sync = funcdispatch_sync()
function_async = asyncio.run(funcdispatch_async(), debug=False)


def test_module_funcdispatch():
    assert module_sync is True
    assert module_async is False
    assert module_sync_no_thread == module_sync_to_thread


def test_function_funcdispatch():
    assert function_sync is True
    assert function_async is False


# def test_funcdispatch_sync(caplog):
#     assert func() is True
#     assert func1(True) == (True, True)
#     with caplog.at_level(verboselogs.SPAM, logger=logger.name):
#         msg = 'log_sync'
#         logger.setLevel(verboselogs.SPAM)
#         logger.spam(msg)
#         assert msg in caplog.text
#
#
# @pytest.mark.asyncio
# async def test_funcdispatch_async(caplog):
#     await to_thread(funcdispatch_sync)
#     assert await func() is False
#     assert await func1(False) == (False, False)
#     with caplog.at_level(verboselogs.SPAM, logger=logger.name):
#         msg = 'log_async'
#         logger.setLevel(verboselogs.SPAM)
#         await logger.spam(msg)
#         assert msg in caplog.text


def to_thread_sync():
    return True


async def to_thread_async():
    # noinspection PyUnusedLocal
    stack_context = 3

    await to_thread(to_thread_sync)

    result = list()
    for coro in as_completed([func(),
                              sync()]):
        r = await coro
        result.append(r)
    assert True in result
    assert False in result
    assert await asyncio.ensure_future(func()) is False
    assert await asyncio.gather(func()) == [False]

    task = create_task(func())
    assert isinstance(task, asyncio.Task)

asyncio.run(to_thread_async(), debug=False)



# -*- coding: utf-8 -*-
"""Nmap Samples."""
import inspect

add = dict({field: {
    "finished": {
        "time": "1611665445", "timestr": "Tue Jan 26 12:50:45 2021",
        "summary": "Nmap done at Tue Jan 26 12:50:45 2021; 1 IP address (1 host up) scanned in 394.81 seconds",
        "elapsed": "394.81", "exit": "success"
    }, "hosts": {"up": "1", "down": "0", "total": "1"}
} if field == 'runstats' else str() for field in
            ["runstats", "scaninfo", "scanner", "start", "startstr", "verbose", "version",
             "xmloutputversion"]})
samples = {
    # tcp
    '94.130.131.107': dict(
        host={
            "starttime": "1611663986",
            "endtime": "1611664445",
            "status": {"state": "up", "reason": "user-set", "reason_ttl": "0"},
            "address": {"addr": "94.130.131.107", "addrtype": "ipv4"},
            "hostnames": {"hostname": {"name": "static.107.131.130.94.clients.your-server.de", "type": "PTR"}},
            "ports": {
                "extraports": [{
                    "state": "open|filtered", "count": "131070",
                    "extrareasons": {"reason": "no-responses", "count": "131070"}
                }, {
                    "state": "filtered", "count": "65533",
                    "extrareasons": {"reason": "no-responses", "count": "65533"}
                }],
                "port": [{
                    "protocol": "tcp", "portid": "80",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "44"},
                    "service": {"name": "http", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "443",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "44"},
                    "service": {"name": "https", "method": "table", "conf": "3"}
                }]
            }, "times": {"srtt": "86246", "rttvar": "134", "to": "100000"}
        },
    ) | add,
    '136.243.155.166': dict(
        host={
            "starttime": "1611733247", "endtime": "1611759487",
            "status": {"state": "up", "reason": "user-set", "reason_ttl": "0"},
            "address": {"addr": "136.243.155.166", "addrtype": "ipv4"},
            "hostnames": {"hostname": {"name": "static.166.155.243.136.clients.your-server.de", "type": "PTR"}},
            "ports": {
                "extraports": [{
                    "state": "open|filtered", "count": "131070",
                    "extrareasons": {"reason": "no-responses", "count": "131070"}
                }, {
                    "state": "filtered", "count": "65535",
                    "extrareasons": {"reason": "no-responses", "count": "65535"}
                }]
            }
        },
    ) | add,
    '88.99.27.146': dict(
        host={
            "starttime": "1611662482", "endtime": "1611732374",
            "status": {"state": "up", "reason": "user-set", "reason_ttl": "0"},
            "address": {"addr": "88.99.27.146", "addrtype": "ipv4"},
            "hostnames": {"hostname": {"name": "static.146.27.99.88.clients.your-server.de", "type": "PTR"}},
            "ports": {
                "extraports": [{
                    "state": "closed", "count": "131015",
                    "extrareasons": [{"reason": "resets", "count": "65532"},
                                     {"reason": "port-unreaches", "count": "65483"}]
                }, {
                    "state": "open|filtered", "count": "65295",
                    "extrareasons": {"reason": "no-responses", "count": "65295"}
                }, {
                    "state": "filtered", "count": "293",
                    "extrareasons": [{"reason": "proto-unreaches", "count": "292"},
                                     {"reason": "no-response", "count": "1"}]
                }],
                "port": [{
                    "protocol": "tcp", "portid": "22",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "44"},
                    "service": {"name": "ssh", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "222",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "44"},
                    "service": {"name": "rsh-spx", "method": "table", "conf": "3"}
                }]
            }, "times": {"srtt": "86406", "rttvar": "132", "to": "100000"}
        },
    ) | add,
    '88.99.100.233': dict(
        host={
            "starttime": "1611733255", "endtime": "1611759495",
            "status": {"state": "up", "reason": "user-set", "reason_ttl": "0"},
            "address": {"addr": "88.99.100.233", "addrtype": "ipv4"},
            "hostnames": {"hostname": {"name": "static.88-99-100-233.clients.your-server.de", "type": "PTR"}},
            "ports": {
                "extraports": [{
                    "state": "open|filtered", "count": "131070",
                    "extrareasons": {"reason": "no-responses", "count": "131070"}
                }, {
                    "state": "filtered", "count": "65535",
                    "extrareasons": {"reason": "no-responses", "count": "65535"}
                }],
                "port": [{
                    "protocol": "tcp", "portid": "22",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "44"},
                    "service": {
                        "name": "ssh", "product": "OpenSSH", "version": "7.6p1 Ubuntu 4ubuntu0.3",
                        "extrainfo": "Ubuntu Linux; protocol 2.0", "ostype": "Linux", "method": "probed",
                        "conf": "10",
                        "cpe": ["cpe:/a:openbsd:openssh:7.6p1", "cpe:/o:linux:linux_kernel"]
                    }, "script": {
                        "id": "ssh-hostkey",
                        "output": "\n  2048 ad:83:6c:ef:e4:45:f6:0f:d3:5e:a6:4f:f2:f8:0c:c2 (RSA)\n  256 "
                                  "09:cb:2e:c5:d4:4b:59:0f:50:48:b5:95:c8:1a:7d:ec (ECDSA)\n  256 "
                                  "92:b9:e9:82:fb:26:bc:c2:bf:72:00:9b:ca:81:12:87 (ED25519)",
                        "table": [{
                            "elem": [{"key": "fingerprint", "#text": "ad836cefe445f60fd35ea64ff2f80cc2"}, {
                                "key": "key",
                                "#text":
                                    "x"
                            }, {"key": "type", "#text": "ssh-rsa"}, {"key": "bits", "#text": "2048"}]
                        }, {
                            "elem": [{"key": "fingerprint", "#text": "09cb2ec5d44b590f5048b595c81a7dec"}, {
                                "key": "key",
                                "#text":
                                    "xx"
                            }, {"key": "type", "#text": "ecdsa-sha2-nistp256"}, {"key": "bits", "#text": "256"}]
                        }, {
                            "elem": [{"key": "fingerprint", "#text": "92b9e982fb26bcc2bf72009bca811287"}, {
                                "key": "key",
                                "#text": "xxx"
                            }, {"key": "type", "#text": "ssh-ed25519"}, {"key": "bits", "#text": "256"}]
                        }]
                    }
                }, {
                    "protocol": "tcp", "portid": "80",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "44"}, "service": {
                        "name": "http", "product": "nginx", "version": "1.14.0", "extrainfo": "Ubuntu",
                        "ostype": "Linux",
                        "method": "probed", "conf": "10",
                        "cpe": ["cpe:/a:igor_sysoev:nginx:1.14.0", "cpe:/o:linux:linux_kernel"]
                    }
                }, {
                    "protocol": "tcp", "portid": "443",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "44"},
                    "service": {
                        "name": "http", "product": "nginx", "version": "1.14.0", "extrainfo": "Ubuntu",
                        "ostype": "Linux",
                        "tunnel": "ssl", "method": "probed", "conf": "10",
                        "cpe": ["cpe:/a:igor_sysoev:nginx:1.14.0", "cpe:/o:linux:linux_kernel"]
                    },
                    "script": [
                        {
                            "id": "http-server-header", "output": "nginx/1.14.0 (Ubuntu)",
                            "elem": "nginx/1.14.0 (Ubuntu)"
                        }, {
                            "id": "http-title", "output": "CodiMD - Collaborative markdown notes",
                            "elem": {"key": "title", "#text": "CodiMD - Collaborative markdown notes"}
                        }, {
                            "id": "ssl-cert",
                            "output": "Subject: commonName=hackmd.nference.net\nSubject Alternative Name: "
                                      "DNS:hackmd.nference.net\nNot valid before: 2020-09-21T23:49:42\nNot valid "
                                      "after:  "
                                      "2020-12-20T23:49:42",
                            "table": [
                                {"key": "subject", "elem": {"key": "commonName", "#text": "hackmd.nference.net"}}, {
                                    "key": "issuer",
                                    "elem": [{"key": "commonName", "#text": "Let's Encrypt Authority X3"},
                                             {"key": "countryName", "#text": "US"},
                                             {"key": "organizationName", "#text": "Let's Encrypt"}]
                                }, {
                                    "key": "pubkey",
                                    "elem": [{"key": "bits", "#text": "2048"}, {"key": "type", "#text": "rsa"},
                                             {"key": "exponent", "#text": "userdata: 0x55623606d718"},
                                             {"key": "modulus", "#text": "userdata: 0x55623606d758"}]
                                }, {
                                    "key": "extensions", "table": [{
                                        "elem": [{"key": "critical", "#text": "true"},
                                                 {
                                                     "key": "name",
                                                     "#text": "X509v3 Key Usage"
                                                 }, {
                                                     "key": "value",
                                                     "#text": "Digital Signature, "
                                                              "Key Encipherment"
                                                 }]
                                    }, {
                                        "elem": [{
                                            "key": "value",
                                            "#text": "TLS Web Server "
                                                     "Authentication, "
                                                     "TLS Web Client "
                                                     "Authentication"
                                        }, {
                                            "key": "name",
                                            "#text": "X509v3 Extended Key "
                                                     "Usage"
                                        }]
                                    }, {
                                        "elem": [{"key": "critical", "#text": "true"},
                                                 {
                                                     "key": "name",
                                                     "#text": "X509v3 Basic "
                                                              "Constraints"
                                                 },
                                                 {"key": "value", "#text": "CA:FALSE"}]
                                    }, {
                                        "elem": [{
                                            "key": "value",
                                            "#text":
                                                "20:1E:54:F7:9C:80:47:0C:05:64:27:C9:17:3C:58:0D:5A:56:F2:46"
                                        }, {
                                            "key": "name",
                                            "#text": "X509v3 Subject Key "
                                                     "Identifier"
                                        }]
                                    }, {
                                        "elem": [{
                                            "key": "value",
                                            "#text":
                                                "keyid:A8:4A:6A:63:04:7D:DD:BA:E6:D1:39:B7:A6:45:65:EF:F3:A8:EC:A1"
                                        }, {
                                            "key": "name",
                                            "#text": "X509v3 Authority Key "
                                                     "Identifier"
                                        }]
                                    }, {
                                        "elem": [{
                                            "key": "value",
                                            "#text": "OCSP - "
                                                     "URI:https://ocsp.int-x3.letsencrypt.org\nCA Issuers - "
                                                     "URI:https://cert.int-x3.letsencrypt.org/"
                                        }, {
                                            "key": "name",
                                            "#text": "Authority Information"
                                                     " Access"
                                        }]
                                    }, {
                                        "elem": [{
                                            "key": "value",
                                            "#text": "DNS:hackmd.nference.net"
                                        }, {
                                            "key": "name",
                                            "#text": "X509v3 Subject "
                                                     "Alternative Name"
                                        }]
                                    }, {
                                        "elem": [{
                                            "key": "value",
                                            "#text": "Policy: 2.23.140.1.2.1\nPolicy: 1.3.6.1.4.1.44947.1.1.1\n  "
                                                     "CPS: https://cps.letsencrypt.org"
                                        }, {
                                            "key": "name",
                                            "#text": "X509v3 Certificate Policies"
                                        }]
                                    }, {
                                        "elem": [{
                                            "key": "value",
                                            "#text": "Signed Certificate Timestamp:\n    Version   : v1 (0x0)\n   "
                                                     " Log ID    : "
                                                     "5E:A7:73:F9:DF:56:C0:E7:B5:36:48:7D:D0:49:E0:32:\n          "
                                                     "      7A:91:9A:0C:84:A1:12:12:84:18:75:96:81:71:45:58\n    "
                                                     "Timestamp : Sep 22 00:49:42.425 2020 GMT\n    Extensions: "
                                                     "none\n    Signature : ecdsa-with-SHA256\n                "
                                                     "30:46:02:21:00:BD:A7:7E:05:99:00:3E:45:39:EE:05:\n          "
                                                     "      FF:B9:0A:6C:A5:75:BE:3E:26:DE:86:74:9B:FF:4C:68:\n    "
                                                     "            "
                                                     "0A:78:97:99:EA:02:21:00:8B:47:B9:74:21:21:D5:DE:\n          "
                                                     "      65:76:E9:28:5D:1E:C6:CE:F7:B5:9A:1B:19:6A:24:96:\n    "
                                                     "            97:81:F4:58:60:F3:EE:95\nSigned Certificate "
                                                     "Timestamp:\n    Version   : v1 (0x0)\n    Log ID    : "
                                                     "07:B7:5C:1B:E5:7D:68:FF:F1:B0:C6:1D:23:15:C7:BA:\n          "
                                                     "      E6:57:7C:57:94:B7:6A:EE:BC:61:3A:1A:69:D3:A2:1C\n    "
                                                     "Timestamp : Sep 22 00:49:42.457 2020 GMT\n    Extensions: "
                                                     "none\n    Signature : ecdsa-with-SHA256\n                "
                                                     "30:45:02:21:00:B7:2D:AA:58:27:33:C1:F0:BD:BB:33:\n          "
                                                     "      98:44:C7:88:83:D4:28:A7:E4:AD:9D:2B:38:12:54:FE:\n    "
                                                     "            "
                                                     "37:B3:22:4C:73:02:20:17:8E:7E:F8:39:73:8C:7B:2C:\n          "
                                                     "      7B:0D:07:72:32:90:F3:25:93:4A:B6:EA:4E:43:06:47:\n    "
                                                     "            FF:E2:74:B6:59:80:0A"
                                        }, {
                                            "key": "name",
                                            "#text": "CT Precertificate SCTs"
                                        }]
                                    }]
                                }, {
                                    "key": "validity", "elem": [{"key": "notAfter", "#text": "2020-12-20T23:49:42"},
                                                                {
                                                                    "key": "notBefore",
                                                                    "#text": "2020-09-21T23:49:42"
                                                                }]
                                }], "elem": [{"key": "sig_algo", "#text": "sha256WithRSAEncryption"},
                                             {"key": "md5", "#text": "5f6a165576ca75fb6bdc79e2b7689bbf"},
                                             {"key": "sha1", "#text": "9337e8940a5e73c63e4799803b9da0021e740961"}, {
                                                 "key": "pem",
                                                 "#text": "-----BEGIN "
                                                          "xxx=\n-----END CERTIFICATE-----"
                                             }]
                        }, {"id": "tls-alpn", "output": "\n  h2\n  http/1.1", "elem": ["h2", "http/1.1"]},
                        {"id": "tls-nextprotoneg", "output": "\n  h2\n  http/1.1", "elem": ["h2", "http/1.1"]}]
                }, {
                    "protocol": "tcp", "portid": "3000",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "43"},
                    "service": {
                        "name": "http", "product": "Node.js Express framework", "method": "probed", "conf": "10",
                        "cpe": "cpe:/a:nodejs:node.js"
                    }
                }]
            }
        },
    ) | add,
    '54.39.18.19': dict(
        host={
            "starttime": "1611662528", "endtime": "1611732261",
            "status": {"state": "up", "reason": "user-set", "reason_ttl": "0"},
            "address": {"addr": "54.39.18.19", "addrtype": "ipv4"},
            "hostnames": {"hostname": {"name": "ns556065.ip-54-39-18.net", "type": "PTR"}}, "ports": {
                "extraports": [{
                    "state": "closed", "count": "131011",
                    "extrareasons": [{"reason": "resets", "count": "65530"},
                                     {"reason": "port-unreaches", "count": "65481"}]
                }, {
                    "state": "open|filtered", "count": "65320",
                    "extrareasons": {"reason": "no-responses", "count": "65320"}
                }, {
                    "state": "filtered", "count": "270",
                    "extrareasons": [{"reason": "proto-unreaches", "count": "269"},
                                     {"reason": "no-response", "count": "1"}]
                }],
                "port": [{
                    "protocol": "tcp", "portid": "22",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "ssh", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "111",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "rpcbind", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "3128",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "squid-http", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "8006",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "wpl-analytics", "method": "table", "conf": "3"}
                }]
            }, "times": {"srtt": "15860", "rttvar": "2261", "to": "100000"}
        },
    ) | add,
    '135.181.36.57': dict(
        host={
            "starttime": "1611734581", "endtime": "1611735176",
            "status": {"state": "up", "reason": "user-set", "reason_ttl": "0"},
            "address": {"addr": "135.181.36.57", "addrtype": "ipv4"},
            "hostnames": {"hostname": {"name": "static.57.36.181.135.clients.your-server.de", "type": "PTR"}},
            "ports": {
                "extraports": [{
                    "state": "open|filtered", "count": "131067",
                    "extrareasons": {"reason": "no-responses", "count": "131067"}
                }, {
                    "state": "filtered", "count": "65532",
                    "extrareasons": {"reason": "no-responses", "count": "65532"}
                }],
                "port": [{
                    "protocol": "tcp", "portid": "22",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "27"},
                    "service": {"name": "ssh", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "80",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "27"},
                    "service": {"name": "http", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "443",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "24"},
                    "service": {"name": "https", "method": "table", "conf": "3"}
                }, {
                    "protocol": "udp", "portid": "22", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "27"
                    }, "service": {"name": "ssh", "method": "table", "conf": "3"}
                }, {
                    "protocol": "udp", "portid": "80", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "27"
                    }, "service": {"name": "http", "method": "table", "conf": "3"}
                }, {
                    "protocol": "udp", "portid": "443", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "27"
                    }, "service": {"name": "https", "method": "table", "conf": "3"}
                }]
            }, "times": {"srtt": "102370", "rttvar": "1235", "to": "107310"}
        },
    ) | add,
    '195.201.80.223': dict(
        host={
            "starttime": "1611778194", "endtime": "1611781327",
            "status": {"state": "up", "reason": "user-set", "reason_ttl": "0"},
            "address": {"addr": "195.201.80.223", "addrtype": "ipv4"},
            "hostnames": {"hostname": {"name": "static.223.80.201.195.clients.your-server.de", "type": "PTR"}},
            "ports": {
                "extraports": [{
                    "state": "open|filtered", "count": "131065",
                    "extrareasons": {"reason": "no-responses", "count": "131065"}
                }, {
                    "state": "filtered", "count": "65530",
                    "extrareasons": {"reason": "no-responses", "count": "65530"}
                }],
                "port": [{
                    "protocol": "tcp", "portid": "4445",
                    "state": {"state": "closed", "reason": "reset", "reason_ttl": "44"},
                    "service": {"name": "upnotifyp", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "8700",
                    "state": {"state": "closed", "reason": "reset", "reason_ttl": "44"}
                }, {
                    "protocol": "tcp", "portid": "8796",
                    "state": {"state": "closed", "reason": "reset", "reason_ttl": "44"}
                }, {
                    "protocol": "tcp", "portid": "8798",
                    "state": {"state": "closed", "reason": "reset", "reason_ttl": "44"},
                    "service": {"name": "unknown", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "8880",
                    "state": {"state": "closed", "reason": "reset", "reason_ttl": "44"},
                    "service": {"name": "cddbp-alt", "method": "table", "conf": "3"}
                }, {
                    "protocol": "udp", "portid": "4445", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "44"
                    }, "service": {"name": "upnotifyp", "method": "table", "conf": "3"}
                }, {
                    "protocol": "udp", "portid": "8700", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "44"
                    }
                }, {
                    "protocol": "udp", "portid": "8796", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "44"
                    }
                }, {
                    "protocol": "udp", "portid": "8798", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "44"
                    }, "service": {"name": "unknown", "method": "table", "conf": "3"}
                }, {
                    "protocol": "udp", "portid": "8880", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "44"
                    }, "service": {"name": "cddbp-alt", "method": "table", "conf": "3"}
                }]
            }, "times": {"srtt": "86617", "rttvar": "286", "to": "100000"}
        },
    ) | add,
    '51.79.72.209': dict(
        host={
            "starttime": "1611662713", "endtime": "1611732636",
            "status": {"state": "up", "reason": "user-set", "reason_ttl": "0"},
            "address": {"addr": "51.79.72.209", "addrtype": "ipv4"},
            "hostnames": {"hostname": {"name": "ns567760.ip-51-79-72.net", "type": "PTR"}}, "ports": {
                "extraports": [{
                    "state": "closed", "count": "196519",
                    "extrareasons": [{"reason": "aborts", "count": "65535"},
                                     {"reason": "resets", "count": "65516"},
                                     {"reason": "port-unreaches", "count": "65468"}]
                }, {
                    "state": "open|filtered", "count": "67",
                    "extrareasons": {"reason": "no-responses", "count": "67"}
                }],
                "port": [{
                    "protocol": "tcp", "portid": "22",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "ssh", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "25", "state": {
                        "state": "filtered", "reason": "no-response", "reason_ttl": "0"
                    }, "service": {"name": "smtp", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "80",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "http", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "443",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "https", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "1935",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "rtmp", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "3000",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "ppp", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "3005",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "deslogin", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "5060",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "sip", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "5066",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "stanag-5066", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "5070",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "vtsas", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "5080",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "onscreen", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "5090",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "unknown", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "7443",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {
                        "name": "oracleas-https", "method": "table", "conf": "3"
                    }
                }, {
                    "protocol": "tcp", "portid": "8021",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "ftp-proxy", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "8080",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "http-proxy", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "8081",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {
                        "name": "blackice-icecap", "method": "table", "conf": "3"
                    }
                }, {
                    "protocol": "tcp", "portid": "8082",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {
                        "name": "blackice-alerts", "method": "table", "conf": "3"
                    }
                }, {
                    "protocol": "tcp", "portid": "8888",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {
                        "name": "sun-answerbook", "method": "table", "conf": "3"
                    }
                }, {
                    "protocol": "tcp", "portid": "9999", "state": {
                        "state": "filtered", "reason": "no-response", "reason_ttl": "0"
                    }, "service": {"name": "abyss", "method": "table", "conf": "3"}
                }]
            }, "times": {"srtt": "15359", "rttvar": "534", "to": "100000"}
        },
    ) | add,
    '78.47.226.47': dict(
        host={
            "starttime": "1611663986",
            "endtime": "1611664445",
            "status": {"state": "up", "reason": "user-set", "reason_ttl": "0"},
            "address": {"addr": "78.47.226.47", "addrtype": "ipv4"},
            "hostnames": {"hostname": {"name": "static.107.131.130.94.clients.your-server.de", "type": "PTR"}},
            "ports": {
                "extraports": [{
                    "state": "open|filtered", "count": "131070",
                    "extrareasons": {"reason": "no-responses", "count": "131070"}
                }, {
                    "state": "filtered", "count": "65533",
                    "extrareasons": {"reason": "no-responses", "count": "65533"}
                }],
                "port": [{
                    "protocol": "tcp", "portid": "80",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "44"},
                    "service": {"name": "http", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "443",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "44"},
                    "service": {"name": "https", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "22",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "44"},
                    "service": {"name": "ssh", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "222",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "44"},
                    "service": {"name": "rsh-spx", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "111",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "rpcbind", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "3128",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "squid-http", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "8006",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "wpl-analytics", "method": "table", "conf": "3"}
                }, {
                    "protocol": "udp", "portid": "22", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "27"
                    }, "service": {"name": "ssh", "method": "table", "conf": "3"}
                }, {
                    "protocol": "udp", "portid": "80", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "27"
                    }, "service": {"name": "http", "method": "table", "conf": "3"}
                }, {
                    "protocol": "udp", "portid": "443", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "27"
                    }, "service": {"name": "https", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "4445",
                    "state": {"state": "closed", "reason": "reset", "reason_ttl": "44"},
                    "service": {"name": "upnotifyp", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "8700",
                    "state": {"state": "closed", "reason": "reset", "reason_ttl": "44"}
                }, {
                    "protocol": "tcp", "portid": "8796",
                    "state": {"state": "closed", "reason": "reset", "reason_ttl": "44"}
                }, {
                    "protocol": "tcp", "portid": "8798",
                    "state": {"state": "closed", "reason": "reset", "reason_ttl": "44"},
                    "service": {"name": "unknown", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "8880",
                    "state": {"state": "closed", "reason": "reset", "reason_ttl": "44"},
                    "service": {"name": "cddbp-alt", "method": "table", "conf": "3"}
                }, {
                    "protocol": "udp", "portid": "4445", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "44"
                    }, "service": {"name": "upnotifyp", "method": "table", "conf": "3"}
                }, {
                    "protocol": "udp", "portid": "8700", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "44"
                    }
                }, {
                    "protocol": "udp", "portid": "8796", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "44"
                    }
                }, {
                    "protocol": "udp", "portid": "8798", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "44"
                    }, "service": {"name": "unknown", "method": "table", "conf": "3"}
                }, {
                    "protocol": "udp", "portid": "8880", "state": {
                        "state": "closed", "reason": "port-unreach", "reason_ttl": "44"
                    }, "service": {"name": "cddbp-alt", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "25", "state": {
                        "state": "filtered", "reason": "no-response", "reason_ttl": "0"
                    }, "service": {"name": "smtp", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "1935",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "rtmp", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "3000",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "ppp", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "3005",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "deslogin", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "5060",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "sip", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "5066",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "stanag-5066", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "5070",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "vtsas", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "5080",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "onscreen", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "5090",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "unknown", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "7443",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {
                        "name": "oracleas-https", "method": "table", "conf": "3"
                    }
                }, {
                    "protocol": "tcp", "portid": "8021",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "ftp-proxy", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "8080",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {"name": "http-proxy", "method": "table", "conf": "3"}
                }, {
                    "protocol": "tcp", "portid": "8081",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {
                        "name": "blackice-icecap", "method": "table", "conf": "3"
                    }
                }, {
                    "protocol": "tcp", "portid": "8082",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {
                        "name": "blackice-alerts", "method": "table", "conf": "3"
                    }
                }, {
                    "protocol": "tcp", "portid": "8888",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "45"},
                    "service": {
                        "name": "sun-answerbook", "method": "table", "conf": "3"
                    }
                }, {
                    "protocol": "tcp", "portid": "9999", "state": {
                        "state": "filtered", "reason": "no-response", "reason_ttl": "0"
                    }, "service": {"name": "abyss", "method": "table", "conf": "3"}
                }]
            }, "times": {"srtt": "86246", "rttvar": "134", "to": "100000"}
        },
    ) | add,
    # vpn.nferxops.net
    '195.201.240.239': dict(
        host={
            "starttime": "1611733267", "endtime": "1611759507",
            "status": {"state": "up", "reason": "user-set", "reason_ttl": "0"},
            "address": {"addr": "195.201.240.239", "addrtype": "ipv4"},
            "hostnames": {"hostname": {"name": "static.239.240.201.195.clients.your-server.de", "type": "PTR"}},
            "ports": {
                "extraports": [{
                    "state": "open|filtered", "count": "131070",
                    "extrareasons": {"reason": "no-responses", "count": "131070"}
                }, {
                    "state": "filtered", "count": "65535",
                    "extrareasons": {"reason": "no-responses", "count": "65535"}
                }]
            }
        },
    ) | add,
    '4.4.4.4': dict(
        host={
            "starttime": "1611733267",
            "endtime": "1611759507",
            "status": {"state": "up", "reason": "user-set", "reason_ttl": "0"},
            "address": {"addr": "195.201.240.239", "addrtype": "ipv4"},
            "hostnames": {"hostname": {"name": "static.239.240.201.195.clients.your-server.de", "type": "PTR"}},
            "ports": {
                "extraports": [{
                    "state": "open|filtered", "count": "131070",
                    "extrareasons": {"reason": "no-responses", "count": "131070"}
                }, {
                    "state": "filtered", "count": "65535",
                    "extrareasons": {"reason": "no-responses", "count": "65535"}
                }]
            }
        },
    ) | add,
    '8.8.8.8': {
        "scanner": "nmap",
        "args": "nmap -R -r -p- -T4 -oX - -A 144.217.183.113",
        "start": "1602660951",
        "startstr": "Wed Oct 14 07:35:51 2020",
        "version": "7.80",
        "xmloutputversion": "1.04",
        "scaninfo": {"type": "syn", "protocol": "tcp", "numservices": "65535", "services": "1-65535"},
        "verbose": {"level": "0"},
        "debugging": {"level": "0"},
        "host": {
            "starttime": "1602660952", "endtime": "1602673003",
            "status": {"state": "up", "reason": "echo-reply", "reason_ttl": "46"},
            "address": {"addr": "144.217.183.113", "addrtype": "ipv4"},
            "hostnames": {"hostname": {"name": "ns556676.ip-144-217-183.net", "type": "PTR"}},
            "ports": {
                "extraports": {
                    "state": "filtered", "count": "65534",
                    "extrareasons": {"reason": "no-responses", "count": "65534"}
                },
                "port": {
                    "protocol": "tcp",
                    "portid": "80",
                    "state": {"state": "open", "reason": "syn-ack", "reason_ttl": "46"},
                    "service": {
                        "name": "http",
                        "servicefp": "SF-Port80-TCP:V=7.80%I=7%D=10/14%Time=5F86D8B9%P=x86_64-pc-linux-gnu%r("
                                     "GetRequest,C4,"
                                     "\"HTTP/1\\.0\\x20301\\x20Moved\\x20Permanently\\r\\nContent-Type:\\x20text"
                                     "/html;\\x20charset=utf-8\\r\\nLocation:\\x20https:///\\r\\nDate:\\x20Wed,"
                                     "\\x2014\\x20Oct\\x202020\\x2010:53:44\\x20GMT\\r\\nContent-Length:\\x2044"
                                     "\\r\\n\\r\\n<a\\x20href=\\\"https:///\\\">Moved\\x20Permanently</a>\\.\\n"
                                     "\\n\")%r(HTTPOptions,6F,"
                                     "\"HTTP/1\\.0\\x20301\\x20Moved\\x20Permanently\\r\\nLocation:\\x20https"
                                     ":///\\r\\nDate:\\x20Wed,"
                                     "\\x2014\\x20Oct\\x202020\\x2010:53:45\\x20GMT\\r\\nContent-Length:\\x200\\r"
                                     "\\n\\r\\n\")%r(RTSPRequest,67,"
                                     "\"HTTP/1\\.1\\x20400\\x20Bad\\x20Request\\r\\nContent-Type:\\x20text/plain"
                                     ";\\x20charset=utf-8\\r\\nConnection:\\x20close\\r\\n\\r\\n400\\x20Bad"
                                     "\\x20Request\")%r(FourOhFourRequest,10A,"
                                     "\"HTTP/1\\.0\\x20301\\x20Moved\\x20Permanently\\r\\nContent-Type:\\x20text"
                                     "/html;\\x20charset=utf-8\\r\\nLocation:\\x20https:///nice%20ports%2C/Tri"
                                     "%6Eity\\.txt%2ebak\\r\\nDate:\\x20Wed,"
                                     "\\x2014\\x20Oct\\x202020\\x2010:53:55\\x20GMT\\r\\nContent-Length:\\x2079"
                                     "\\r\\n\\r\\n<a\\x20href=\\\"https:///nice%20ports%2C/Tri%6Eity\\.txt%2ebak"
                                     "\\\">Moved\\x20Permanently</a>\\.\\n\\n\")%r(GenericLines,67,"
                                     "\"HTTP/1\\.1\\x20400\\x20Bad\\x20Request\\r\\nContent-Type:\\x20text/plain"
                                     ";\\x20charset=utf-8\\r\\nConnection:\\x20close\\r\\n\\r\\n400\\x20Bad"
                                     "\\x20Request\")%r(Help,67,"
                                     "\"HTTP/1\\.1\\x20400\\x20Bad\\x20Request\\r\\nContent-Type:\\x20text/plain"
                                     ";\\x20charset=utf-8\\r\\nConnection:\\x20close\\r\\n\\r\\n400\\x20Bad"
                                     "\\x20Request\")%r(SSLSessionReq,67,"
                                     "\"HTTP/1\\.1\\x20400\\x20Bad\\x20Request\\r\\nContent-Type:\\x20text/plain"
                                     ";\\x20charset=utf-8\\r\\nConnection:\\x20close\\r\\n\\r\\n400\\x20Bad"
                                     "\\x20Request\")%r(TerminalServerCookie,67,"
                                     "\"HTTP/1\\.1\\x20400\\x20Bad\\x20Request\\r\\nContent-Type:\\x20text/plain"
                                     ";\\x20charset=utf-8\\r\\nConnection:\\x20close\\r\\n\\r\\n400\\x20Bad"
                                     "\\x20Request\")%r(TLSSessionReq,67,"
                                     "\"HTTP/1\\.1\\x20400\\x20Bad\\x20Request\\r\\nContent-Type:\\x20text/plain"
                                     ";\\x20charset=utf-8\\r\\nConnection:\\x20close\\r\\n\\r\\n400\\x20Bad"
                                     "\\x20Request\")%r(Kerberos,67,"
                                     "\"HTTP/1\\.1\\x20400\\x20Bad\\x20Request\\r\\nContent-Type:\\x20text/plain"
                                     ";\\x20charset=utf-8\\r\\nConnection:\\x20close\\r\\n\\r\\n400\\x20Bad"
                                     "\\x20Request\")%r(LPDString,67,"
                                     "\"HTTP/1\\.1\\x20400\\x20Bad\\x20Request\\r\\nContent-Type:\\x20text/plain"
                                     ";\\x20charset=utf-8\\r\\nConnection:\\x20close\\r\\n\\r\\n400\\x20Bad"
                                     "\\x20Request\");",
                        "method": "probed", "conf": "10"
                    },
                    "script": [{
                        "id": "fingerprint-strings",
                        "output": "\n  FourOhFourRequest: \n    HTTP/1.0 301 Moved Permanently\n    "
                                  "Content-Type: text/html; charset=utf-8\n    Location: "
                                  "https:///nice%20ports%2C/Tri%6Eity.txt%2ebak\n    Date: Wed, "
                                  "14 Oct 2020 10:53:55 GMT\n    Content-Length: 79\n    "
                                  "href=\"https:///nice%20ports%2C/Tri%6Eity.txt%2ebak\">Moved "
                                  "Permanently</a>.\n  GenericLines, Help, Kerberos, LPDString, "
                                  "RTSPRequest, SSLSessionReq, TLSSessionReq, TerminalServerCookie: "
                                  "\n    HTTP/1.1 400 Bad Request\n    Content-Type: text/plain; "
                                  "charset=utf-8\n    Connection: close\n    Request\n  GetRequest: "
                                  "\n    HTTP/1.0 301 Moved Permanently\n    Content-Type: "
                                  "text/html; charset=utf-8\n    Location: https:///\n    Date: "
                                  "Wed, 14 Oct 2020 10:53:44 GMT\n    Content-Length: 44\n    "
                                  "href=\"https:///\">Moved Permanently</a>.\n  HTTPOptions: \n    "
                                  "HTTP/1.0 301 Moved Permanently\n    Location: https:///\n    "
                                  "Date: Wed, 14 Oct 2020 10:53:45 GMT\n    Content-Length: 0",
                        "elem": [{
                            "key": "FourOhFourRequest",
                            "#text": "HTTP/1.0 301 Moved Permanently\n    Content-Type: "
                                     "text/html; charset=utf-8\n    Location: "
                                     "https:///nice%20ports%2C/Tri%6Eity.txt%2ebak\n    "
                                     "Date: Wed, 14 Oct 2020 10:53:55 GMT\n    "
                                     "Content-Length: 79\n    "
                                     "href=\"https:///nice%20ports%2C/Tri%6Eity.txt%2ebak\">Moved Permanently</a>."
                        }, {
                            "key": "GenericLines, Help, Kerberos, LPDString, RTSPRequest, "
                                   "SSLSessionReq, TLSSessionReq, TerminalServerCookie",
                            "#text": "HTTP/1.1 400 Bad Request\n    Content-Type: "
                                     "text/plain; charset=utf-8\n    Connection: close\n   "
                                     " Request"
                        }, {
                            "key": "GetRequest",
                            "#text": "HTTP/1.0 301 Moved Permanently\n    Content-Type: "
                                     "text/html; charset=utf-8\n    Location: https:///\n  "
                                     "  Date: Wed, 14 Oct 2020 10:53:44 GMT\n    "
                                     "Content-Length: 44\n    href=\"https:///\">Moved "
                                     "Permanently</a>."
                        }, {
                            "key": "HTTPOptions",
                            "#text": "HTTP/1.0 301 Moved Permanently\n    Location: "
                                     "https:///\n    Date: Wed, 14 Oct 2020 10:53:45 GMT\n "
                                     "   Content-Length: 0"
                        }]
                    }, {
                        "id": "https-redirect",
                        "output": "ERROR: Script execution failed (use -d to debug)"
                    }]
                }
            },
            "os": {
                "portused": {"state": "open", "proto": "tcp", "portid": "80"}, "osmatch": [{
                    "name": "Linux "
                            "2.6.32",
                    "accuracy": "92",
                    "line": "54126",
                    "osclass": {
                        "type":
                            "general "
                            "purpose",
                        "vendor":
                            "Linux",
                        "osfamily":
                            "Linux",
                        "osgen": "2.6.X",
                        "accuracy": "92",
                        "cpe":
                            "cpe:/o:linux:linux_kernel:2.6.32"
                    }
                }, {
                    "name": "Linux "
                            "2.6.32 or"
                            " 3.10",
                    "accuracy": "92",
                    "line": "56650",
                    "osclass": [{
                        "type": "general purpose",
                        "vendor": "Linux",
                        "osfamily": "Linux",
                        "osgen": "2.6.X",
                        "accuracy": "92",
                        "cpe": "cpe:/o:linux:linux_kernel:2.6.32"
                    }, {
                        "type": "general purpose",
                        "vendor": "Linux",
                        "osfamily": "Linux",
                        "osgen": "3.X",
                        "accuracy": "92",
                        "cpe": "cpe:/o:linux:linux_kernel:3.10"
                    }]
                }, {
                    "name": "Linux 4.4",
                    "accuracy": "92",
                    "line": "67202",
                    "osclass": {
                        "type": "general purpose",
                        "vendor": "Linux",
                        "osfamily": "Linux",
                        "osgen": "4.X",
                        "accuracy": "92",
                        "cpe": "cpe:/o:linux:linux_kernel:4.4"
                    }
                }, {
                    "name": "Linux 2.6.32 - 2.6.35",
                    "accuracy": "89",
                    "line": "56133",
                    "osclass": {
                        "type": "general purpose",
                        "vendor": "Linux",
                        "osfamily": "Linux",
                        "osgen": "2.6.X",
                        "accuracy": "89",
                        "cpe": "cpe:/o:linux:linux_kernel:2.6.32"
                    }
                }, {
                    "name": "Linux 2.6.32 - 2.6.39",
                    "accuracy": "89",
                    "line": "56230",
                    "osclass": {
                        "type": "general purpose",
                        "vendor": "Linux",
                        "osfamily": "Linux",
                        "osgen": "2.6.X",
                        "accuracy": "89",
                        "cpe": "cpe:/o:linux:linux_kernel:2.6"
                    }
                }, {
                    "name": "Linux 4.0",
                    "accuracy": "88",
                    "line": "66814",
                    "osclass": {
                        "type": "general purpose",
                        "vendor": "Linux",
                        "osfamily": "Linux",
                        "osgen": "4.X",
                        "accuracy": "88",
                        "cpe": "cpe:/o:linux:linux_kernel:4.0"
                    }
                }, {
                    "name": "Linux 2.6.32 - 3.0",
                    "accuracy": "87",
                    "line": "56293",
                    "osclass": [{
                        "type": "general purpose",
                        "vendor": "Linux",
                        "osfamily": "Linux",
                        "osgen": "2.6.X",
                        "accuracy": "87",
                        "cpe": "cpe:/o:linux:linux_kernel:2.6"
                    }, {
                        "type": "general purpose",
                        "vendor": "Linux",
                        "osfamily": "Linux",
                        "osgen": "3.X",
                        "accuracy": "87",
                        "cpe": "cpe:/o:linux:linux_kernel:3"
                    }]
                }, {
                    "name": "Linux 2.6.18 - 2.6.22",
                    "accuracy": "86",
                    "line": "49721",
                    "osclass": {
                        "type": "general purpose",
                        "vendor": "Linux",
                        "osfamily": "Linux",
                        "osgen": "2.6.X",
                        "accuracy": "86",
                        "cpe": "cpe:/o:linux:linux_kernel:2.6"
                    }
                }, {
                    "name": "Linux 3.10",
                    "accuracy": "86",
                    "line": "62820",
                    "osclass": {
                        "type": "general purpose",
                        "vendor": "Linux",
                        "osfamily": "Linux",
                        "osgen": "3.X",
                        "accuracy": "86",
                        "cpe": "cpe:/o:linux:linux_kernel:3.10"
                    }
                }, {
                    "name": "Linux 3.10 - 4.11",
                    "accuracy": "86",
                    "line": "63230",
                    "osclass": [{
                        "type": "general purpose",
                        "vendor": "Linux",
                        "osfamily": "Linux",
                        "osgen": "3.X",
                        "accuracy": "86",
                        "cpe": "cpe:/o:linux:linux_kernel:3"
                    }, {
                        "type": "general purpose",
                        "vendor": "Linux",
                        "osfamily": "Linux",
                        "osgen": "4.X",
                        "accuracy": "86",
                        "cpe": "cpe:/o:linux:linux_kernel:4"
                    }]
                }]
            },
            "uptime": {"seconds": "425573", "lastboot": "Fri Oct  9 12:43:51 2020"},
            "distance": {"value": "29"},
            "tcpsequence": {
                "index": "260", "difficulty": "Good luck!",
                "values": "F6C1243F,3CE9E56F,78E0D47,7D2CEB56,900387FB,B42B064F"
            },
            "ipidsequence": {"class": "All zeros", "values": "0,0,0,0,0,0"},
            "tcptssequence": {"class": "1000HZ", "values": "195CFCAF,195CFD13,195CFD77,195CFDDB,195CFE40,195CFEA4"},
            "trace": {
                "port": "80", "proto": "tcp", "hop": [{"ttl": "7", "ipaddr": "52.93.29.9", "rtt": "1.91"},
                                                      {"ttl": "11", "ipaddr": "100.91.164.89", "rtt": "110.44"},
                                                      {"ttl": "13", "ipaddr": "100.91.222.77", "rtt": "86.81"},
                                                      {"ttl": "19", "ipaddr": "100.91.56.95", "rtt": "84.42"},
                                                      {"ttl": "20", "ipaddr": "100.100.4.127", "rtt": "85.63"},
                                                      {"ttl": "21", "ipaddr": "100.100.76.196", "rtt": "87.22"},
                                                      {"ttl": "22", "ipaddr": "100.100.84.195", "rtt": "66.28"},
                                                      {"ttl": "23", "ipaddr": "100.100.2.26", "rtt": "84.79"},
                                                      {"ttl": "25", "ipaddr": "192.99.146.138", "rtt": "88.82"}, {
                                                          "ttl": "29", "ipaddr": "144.217.183.113", "rtt": "74.74",
                                                          "host": "ns556676.ip-144-217-183.net"
                                                      }]
            },
            "times": {"srtt": "67514", "rttvar": "66054", "to": "331730"}
        },
        "runstats": {
            "finished": {
                "time": "1602673004", "timestr": "Wed Oct 14 10:56:44 2020", "elapsed": "12052.66",
                "summary": "Nmap done at Wed Oct 14 10:56:44 2020; 1 IP address (1 host up) scanned in 12052.66 "
                           "seconds",
                "exit": "success"
            }, "hosts": {"up": "1", "down": "0", "total": "1"}
        },
    },
}
__all__ = tuple(item for item in globals() if not item.startswith('_') and not inspect.ismodule(globals().get(item)))



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['bapy']

package_data = \
{'': ['*'], 'bapy': ['data/*', 'scripts/*']}

install_requires = \
['decorator',
 'devtools',
 'distro',
 'dpath',
 'icecream',
 'environs',
 'furl',
 'gitpython',
 'inflect',
 'intervaltree',
 'jinja2',
 'jsonpickle',
 'loguru',
 'marshmallow',
 'more_itertools',
 'motor',
 'nested_lookup',
 'paramiko',
 'pip',
 'pymongo[srv,tls]',
 'python-box',
 'requests[security]',
 'rich',
 'semver',
 'setuptools',
 'structlog',
 'typer[all]',
 'wheel']

entry_points = \
{'console_scripts': ['bapy = bapy:app', 'localbin = bapy:localbin']}

setup(name='bapy',
      version='1.0.40',
      description='Bapy Package.',
      author='José',
      author_email=None,
      url=None,
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      entry_points=entry_points,
     )



import abc
import ast
import asyncio.events
import collections
import contextlib
import dataclasses
import enum
import functools
import importlib
import inspect
import io
import ipaddress
import os
import pathlib
import pwd
import re
import subprocess
import sys
import threading
import typing
from collections.abc import ByteString as ByteString
from collections.abc import Callable as Callable
from collections.abc import Container as Container
from collections.abc import Generator as Generator
from collections.abc import Iterable as Iterable
from collections.abc import Iterator as Iterator
from collections.abc import KeysView as KeysView
from collections.abc import Mapping as Mapping
from collections.abc import MutableMapping as MutableMapping
from collections.abc import MutableSequence as MutableSequence
from collections.abc import MutableSet as MutableSet
from collections.abc import Sequence as Sequence
from collections.abc import Sized as Sized
from collections.abc import ValuesView as ValuesView
from pkgutil import MetaPathFinder
from shelve import DbfilenameShelf
from types import BuiltinFunctionType
from types import BuiltinMethodType
from types import CodeType
from types import FrameType
from types import FunctionType
from types import GenericAlias
from types import LambdaType
from types import MethodType
from types import ModuleType
from types import SimpleNamespace
from types import TracebackType
from typing import Any
from typing import AnyStr
from typing import Final
from typing import Generic
from typing import Literal
from typing import NamedTuple
from typing import Optional
from typing import overload
from typing import Type
from typing import TypedDict
from typing import TypeVar
from typing import Union

import box
import decorator
import devtools
import distro
import environs
import furl
import git
import inflect
import intervaltree
import jinja2
import rich.console
import semver
import setuptools.command.install
import typer

__all__: tuple[str, ...]
__version__: str
# Defaults
CMS_INSTALL_POST_DEFAULT: Union[_T, bool] = ...
FILE_DEFAULT: Union[_T, bool] = ...
FRAME_INDEX: Union[_T, int] = ...
GIT_VERSIONS: Union[_T, int] = ...
STDOUT_DEFAULT: Union[_T, bool] = ...
SUDO_DEFAULT: Union[_T, bool] = ...

# Vars
Alias = typing._alias
ALL_PORTS: range = ...
APP_CONTEXT: dict[str, Any] = ...
app: typer.Typer = ...
AsyncsUnion = Union[ast.AsyncFor, ast.AsyncWith, ast.Await]
BASE_EXEC_PREFIX: str = ...
BASE_EXECUTABLE: str = ...
BASE_PREFIX: str = ...
# noinspection PyAnnotations
BaseTypesUnion = Union[int, float, list, dict, set, tuple, object, bytes]
BASE_TYPES: set[Type, ...] = ...
Bool = bool
BUILTIN: DictStrAny = ...
BUILTIN_CLASS: TupleType = ...
BUILTIN_CLASS_NO_EXCEPTION: TupleType = ...
BUILTIN_CLASS_DICT: TupleType = ...
BUILTIN_CLASS_NO_DICT: TupleType = ...
BUILTIN_FUNCTION: TupleType = ...
BUILTIN_MODULE_NAMES: Sequence[str] = ...
cancel_all_tasks = asyncio.runners._cancel_all_tasks
console: rich.console.Console
cp: Any = ...
CRLock = threading._CRLock
CURLYBRACKETS: str = ...
current_frames = sys._current_frames
datafield: Final[dataclasses.field]
DATA_MISSING = dataclasses.MISSING
debug: devtools.Debug
DEFAULT_FACTORY = dataclasses._HAS_DEFAULT_FACTORY_CLASS
DefsUnion = Union[ast.FunctionDef, ast.AsyncFunctionDef, ast.ClassDef, ast.Lambda]
Dict = dict
DictStrAny = dict[str, Any]
DISTRO: distro.LinuxDistribution()
EXEC_PREFIX: str = ...
ExceptionUnion = Union[tuple[Type[Exception]], Type[Exception]]
EXECUTABLE: pathlib.Path = ...
EXECUTABLE_SITE: pathlib.Path = ...
FIELD: Final[dataclasses._FIELD]
FIELD_BASE = dataclasses._FIELD_BASE
FIELD_CLASSVAR: Final[dataclasses._FIELD_CLASSVAR]
FIELD_INITVAR: Final[dataclasses._FIELD_INITVAR]
FlagsType = typing.Union[int, re.RegexFlag]
fmic: Any = ...
fmicc: Any = ...
FQDN: str = ...
FRAME: FrameType = ...
Frames = Union[inspect.FrameInfo, FrameType, TracebackType]
FUNCTION_MODULE: str = ...
FunctionTypesUnion = Union[FunctionType, MethodType, LambdaType, BuiltinFunctionType,
                                  BuiltinMethodType]
FUNCTION_TYPES: set[Type, ...]
getframe = sys._getframe
GitCommandWrapperType = git.Repo.GitCommandWrapperType
HOSTNAME: str = ...
HTTP_EXCEPTIONS: TupleType = ...
ic: Any = ...
icc: Any = ...
ID_RSA_PUB: str = ...
INIT_PY: str = ...
inspect_empty = inspect._empty
IPv = typing.Union[ipaddress.IPv4Address, ipaddress.IPv6Address]
IMPORTLIB_BOOTSTRAP: str = ...
IMPORTLIB_BOOTSTRAP_EXTERNAL: str = ...
IMPORTLIB_PYCACHE: str = ...
IteratorTypes = (type(iter('')),)
KALI: bool = ...
LINUX: bool = ...
List = list
USERLOCAL: pathlib.Path = ...
LOCALBIN: pathlib.Path = ...
LOCALHOST: str = ...
LST = Union[list, set, tuple]
LST_TYPES: tuple[Type, ...] = ...
MACOS: bool = ...
MACHINE: str = ...
MANIFEST: str = ...
MatchAnyStr = typing.Match[AnyStr]
MatchCallable = typing.Callable[[MatchAnyStr], AnyStr]
MatchCallableUnion = typing.Union[typing.Callable[[MatchAnyStr], AnyStr], AnyStr]
MatchIterator = typing.Iterator[MatchAnyStr]
MatchOptional = typing.Optional[MatchAnyStr]
META_PATH: list[MetaPathFinder] = ...
ModuleSpec = importlib._bootstrap.ModuleSpec
MONGO_CONF: str = ...
MONGO_EXCEPTIONS: TupleType = ...
NEWLINE: str
NODE: str = ...
OpenIO = Union[io.BufferedRandom, io.BufferedReader, io.BufferedWriter, io.FileIO, io.TextIOWrapper]
PATH_HOOKS: list[Type, FunctionType] = ...
PATHLIBDIR: str = ...
PLATFORM: str = ...
PatternUnion = typing.Union[typing.AnyStr, typing.Pattern[typing.AnyStr]]
plural = inflect.engine().plural
PrimitiveTypesUnion = Union[str, bool, type(None), int, float]
PRIMITIVE_TYPES: set[Type, ...] = ...
NON_REDUCTIBLE_TYPES: set[Type, ...] = ...
print_exception: Any = ...
PROCESSOR: str = ...
PYTHON_IMPLEMENTATION: str = ...
PYTHON_VERSION: str = ...
PYTHON_VERSIONS: tuple[semver.VersionInfo, semver.VersionInfo]
PYTHON_VERSION_TUPLE: typing.Tuple[str, str, str] = ...
RELEASE: str = ...
RunningLoop = asyncio.events._RunningLoop
SeqTuple = Union[typing.MutableSequence, typing.MutableSet, tuple]
SYSCONFIG_PATHS: dict[str, pathlib.Path] = ...
SCRIPTS: pathlib.Path = ...
Simple = SimpleNamespace
SOCKET_VERSION: dict[int, dict[str, int]] = ...
SPECIAL_CHARACTERS: str = ...
SSH_CONFIG: DictStrAny = ...
SSH_CONFIG_TEXT: str = ...
Str = str
SUDO_USER: str = ...
SUDO: bool = ...
SYSPATH: list[str, ...] = ...
SYSPREFIX: str = ...
TEMPDIR: pathlib.Path = ...
ThreadLock = threading.Lock
LockClass = type(ThreadLock())
Tuple = tuple
TupleStr = tuple[str, ...]
TupleType = tuple[Type, ...]
UBUNTU: str = ...
SeqNoStr = Union[typing.Iterator, typing.KeysView, typing.MutableSequence, typing.MutableSet, typing.Sequence,
                        tuple, typing.ValuesView]
SeqUnion = Union[bytes, typing.ByteString, SeqNoStr, str]
VENV: bool = ...
WITHSUDO: str = ...
# TypeVars
_Annotation = TypeVar('_Annotation', bound='Annotation')
_Is = TypeVar('_Is', bound='Is')
_Path = TypeVar('_Path', bound='Path')
_T = TypeVar('_T')
_KT = TypeVar('_KT')
_U = TypeVar('_U')
_VT = TypeVar('_VT')
_T_co = TypeVar('_T_co', covariant=True)  # Any type covariant containers.
# Functions
def aioclosed() -> bool: ...
async def aiocmd(command: Union[str, list], decode: bool = ..., utf8: bool = ...,
                 lines: bool = ...) -> subprocess.CompletedProcess: ...
def aioloop() -> Optional[RunningLoop]: ...
def aioloopid() -> Optional[int]: ...
def aiorunning() -> bool: ...
def allin(origin: Iterable, destination: Iterable) -> bool: ...
def annotations(data: Any, index: int = ...) -> DictStrAny: ...
def annotations_init(data: Any = ..., optional: bool = ..., **kwargs: Any) -> Any: ...
def anyin(origin: Iterable, destination: Iterable) -> Optional[Any]: ...
class _cache_wrapper(Generic[_T]):
    __wrapped__: Callable[..., _T]
    def __call__(self, *args: Any, **kwargs: Any) -> _T: ...
def cache(__func: Callable[..., _T] = ...) -> Union[Callable[[Callable[..., _T]], _cache_wrapper[_T]], _T]: ...
def cmd(command: Iterable, exc: bool = ..., lines: bool = ..., shell: bool = ..., py: bool = ...,
        pysite: bool = ...) -> Union[subprocess.CompletedProcess, int, list, str]: ...
def cmdname(func: Callable, sep: str = ...) -> str: ...
def current_task_name() -> str: ...
@functools.singledispatch
def delete(data: Union[MutableMapping, list], key: Iterable = ...) -> Optional[dict]: ...
@delete.register
def delete_list(data: list, key: Iterable = ...) -> Optional[list]: ...
def dict_sort(data: dict[_KT, _VT], ordered: bool = ...,
              reverse: bool = ...) -> Union[dict[_KT, _VT], collections.OrderedDict[_KT, _VT]]:...
def effect(apply: typing.Callable, data: typing.Iterable) -> Optional[typing.Iterator]: ...
def enumvalue(data: Any) -> Any:...
def filterm(d: dict[_KT, _VT], k: typing.Callable[..., bool] = ...,
            v: typing.Callable[..., bool] = ...) -> typing.MutableMapping[_KT, _VT]: ...
def firstfound(data: typing.Iterable, apply: typing.Callable) -> Any: ...
def flatten(data: LST, recurse: bool = ..., unique: bool = ..., sort: bool = ...) -> LST: ...
def framesimple(data: Any) -> FrameSimple:...
def fromiter(data: typing.Sequence[Any, ...], *args: Union[str, nstr, typing.Iterable[str, nstr]]) -> DictStrAny: ...
def funcdispatch(func: Callable):...
def get(data: Any, *args: Any, default: Any = ..., one: bool = ..., recursive: bool = ...,
        with_keys: bool = ...) -> Any:...
def getcls(data: Any) -> Type[Any]:...
def getf(data: Any, name: str, default: Any = ...) -> Any:...
def getm(data: Union[typing.MutableMapping, Any], name: Any = ...) -> Optional[Any, MISSING]: ...
@overload
def getnostr(data: str, attr: Optional[str] = ...) -> str:...
@overload
def getnostr(data: Any, attr: Optional[str] = ...) -> str:...
def getprops(data: Any) -> DictStrAny: ...
def getset(data: Any, name: str, default: Any = ..., setvalue: bool = ...) -> Any:...
@overload
def getsetstate(data: Any) -> DictStrAny: ...
@overload
def getsetstate(data: Any, state: DictStrAny = ...) -> Any: ...
def has(data: Any, name: Union[str, nstr]) -> bool: ...
def hasget(data: Any, name: Union[str, nstr], default: Any = ...) -> Any: ...
def hasgetany(obj: Any, name: Union[str, nstr], default: Any = ...) -> Any: ...
def importname(data: Any) -> str: ...
def indict(data: typing.MutableMapping, items: typing.MutableMapping = ..., **kwargs: Any) -> bool: ...
def indictr(data: typing.MutableMapping, items: typing.MutableMapping = ..., **kwargs: Any) -> bool: ...
def initimps(path: PathLikeStr = ..., relative: bool = ...) -> tuple[tuple[ModuleType, ...], str, str]: ...
def iscoro(data: Any) -> bool: ...
def iseven(number: int) -> bool: ...
def istype(data: Any) -> bool: ...
def join_newline(data: typing.Iterable[str]) -> str: ...
def localbin(path: Any = __file__) -> None: ...
def map_reduce_even(iterable: typing.Iterable[_T]) -> list[_U, list[_T]]:...
def map_with_args(data: Any, func: typing.Callable, /, *args, pred: typing.Callable = lambda x: True if x else False,
                  split: str = ' ', **kwargs) -> list: ...
def missing(data: Any) -> bool: ...
def newprop(name: str = ..., default: Optional[Any, typing.Callable, functools.partial] = ...) -> property: ...
def noexc(func: typing.Callable[..., _T], *args, default_: Any = ..., exc_: ExceptionUnion = ...,
          **kwargs: Any) -> _T: ...
def notmissing(data: Any) -> bool: ...
def notstart(name: str, start: str = ...): ...
@overload
def objname(data: Any) -> str: ...
@overload
def objname(data: Type[None] = ..., stack: Union[int, inspect.FrameInfo] = ...) -> str: ...
def prefixed(name: str) -> str: ...
def pretty_install(cons: rich.console.Console = ..., expand: bool = ...): ...
def pypifree(name: str, stdout: bool = False) -> bool: ...
def reprcls(data: Any = ..., attrs: typing.Iterable = ..., line: bool = ..., module: bool = ...,
            sort: bool = ..., **kwargs: Any) -> str: ...
def reprkw(data: Any = ..., attrs: typing.Iterable = ..., line: bool = ...,
           sort: bool = ..., start: str = ..., **kwargs: Any) -> str: ...
def sourcepath(data: Any) -> Path: ...
def sourcevars() -> dict[str, str]: ...
@decorator.decorator
def runwarning(func: typing.Callable, *args: Any, **kwargs: Any) -> Any: ...
def splitsep(sep: str = ...): ...
def to_camel(text: str, replace: bool = True) -> str: ...
def toiter(data: Any, split: str = ...) -> Union[typing.Sized, typing.MutableMapping, typing.Sequence,
                                                               typing.MutableSequence]: ...
def tomodules(data: Any, suffix: bool = ...) -> str: ...
def traceback_install(cons: rich.console.Console = ..., extra: int = ..., locs: bool = ...): ...
def varname(index: int = ..., lower: bool = ..., prefix: Optional[str] = ..., sep: str = ...) -> Optional[str]: ...
def _version() -> None: ...
def yield_if(data: Any, pred: typing.Callable = ..., split: str = ...,
             apply: Union[typing.Callable, tuple[Callable, ...]] = ...) -> typing.Generator: ...
def yield_last(data: Any) -> typing.Iterator[tuple[bool, Any, Optional[Any, None]]]: ...
# EnumBase
@functools.total_ordering
class EnumBase(enum.Enum, Generic[_T], _T):
    def __call__(self) -> Any: ...
    def __eq__(self, other: Union[str, Access]) -> bool: ...
    def __gt__(self, other: Union[str, Access]) -> bool: ...
    def __hash__(self) -> int: ...
    def __int__(self) -> int: ...
    def _generate_next_value_(self: str, start: Any, count: Any, last_values: Any) -> str: ...
    @classmethod
    def asdict(cls) -> DictStrAny: ...
    @classmethod
    def attrs(cls) -> list: ...
    @classmethod
    def default(cls) -> Any: ...
    @classmethod
    def default_attr(cls) -> str: ...
    @classmethod
    def default_dict(cls) -> DictStrAny: ...
    @classmethod
    def default_value(cls) -> Any: ...
    describe: tuple = ...
    lower: str = ...
    @classmethod
    def values(cls) -> list: ...
EnumBaseAlias: Alias
class EnumBaseMeta(enum.EnumMeta):
    _member_map_: dict[str, Union[EnumBase, EnumBaseMeta]]
    def __getitem__(cls, item: Any) -> Optional[Access]: ...
    def __class_getitem__(mcs, item: Any) -> Optional[Access]: ...
# Classes
class Access(EnumBase, metaclass=EnumBaseMeta):
    ALL = ...
    PRIVATE = ...
    PROTECTED = ...
    PUBLIC = ...
    @classmethod
    def classify(cls, *args: str, **kwargs: Union[enum.Enum, Any]) -> AccessEnumMembers: ...
    def es(self, name: str) -> bool: ...
    def include(self, name: str) -> Optional[bool]: ...
_AccessEnumMember = Union[dict[str,typing. Union[enum.Enum, Any]], list[str]]
AccessEnumMembers = NamedTuple('AccessEnumMembers', all=_AccessEnumMember, private=_AccessEnumMember,
                                       protected=_AccessEnumMember, public=_AccessEnumMember)
class AllAttr(metaclass=abc.ABCMeta):
    __slots__: TupleStr = ...
    __all__: TupleStr = ...
    @classmethod
    def __subclasshook__(cls, C: Type) -> bool: ...
Annotation = NamedTuple('Annotation', any=bool, args=list[Generic[_Annotation], ...],
                               classvar=bool, cls=Type, default=Any, final=bool,
                               hint=Type, initvar=bool, literal=bool, name=str, optional=bool,
                               origin=Any, union=bool)
class AnnotationsAttr(metaclass=abc.ABCMeta):
    __slots__: TupleStr = ...
    __annotations__: DictStrAny = ...
    @classmethod
    def __subclasshook__(cls, C: Type) -> bool: ...
class AsDictMethod(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def asdict(self, *args: Any, **kwargs: Any) -> DictStrAny: ...
    @classmethod
    def __subclasshook__(cls, C: Type) -> bool: ...
class AsDictProperty(metaclass=abc.ABCMeta):
    @property
    @abc.abstractmethod
    def asdict(self) -> DictStrAny: ...
    @classmethod
    def __subclasshook__(cls, C: Type) -> bool: ...
class Kind(EnumBase, metaclass=EnumBaseMeta):
    CLASSMETHOD = ...
    CLASSVAR = ...
    DATA = ...
    FACTORY = ...
    INITVAR = ...
    METHOD = ...
    PROPERTY = ...
    STATICMETHOD = ...
    UNKNOWN = ...
Attribute = NamedTuple('Attribute', defining=Type, i=_Is[Any], kind=Kind, object=Any, qualname=str)
class BaseState:
    __slots__: TupleStr = ...
    __state__: TupleStr = ...
    def __getstate__(self) -> DictStrAny: ...
    def __setstate__(self, state: DictStrAny) -> BaseState: ...
class BoxKeys(box.Box[str, Any]):
    def __init__(self, keys: Iterable,
                 value: Optional[Union[Type, Literal['lower']]] = ...) -> None: ...
class ChainRV(EnumBase, metaclass=EnumBaseMeta):
    ALL = ...
    FIRST = ...
    UNIQUE = ...
class Chain(collections.ChainMap):
    rv: ChainRV
    default: Any
    maps: list[Union[Iterable, Namedtuple, MutableMapping]]
    def __init__(self, *maps: ..., rv: ChainRV = ..., default: Any = ...) -> None: ...
    def __getitem__(self, key: Any) -> Any: ...
    def __delitem__(self, key: Any) -> None: ...
    def delete(self, key: Any) -> Chain: ...
    def __setitem__(self, key: Any, value: Any) -> None: ...
    def set(self, key: Any, value: Any) -> None: ...
ClassBase = NamedTuple('ClassBase', annotation=dict[str, DictStrAny], attribute=dict[str, Attribute], cls=Type,
                       coro=set[str, ...], data=DictStrAny, i=_Is[Type[Any]], importable=str, init=DictStrAny,
                       module=str, mro=TupleType, mroitems=collections.defaultdict[str, set[str, ]],
                       property=set[str, ...], qualname=str, routine=set[str, ...],
                       signature=dict[Any, MutableMapping[str, Any]], slot=set[str, ...],)
class Class(ClassBase):
    cache: dict[TypesType, Class] = ...
    __slots__ = ()
    def __new__(cls, data: Union[Is, TypesType]) -> Class: ...
    def __iter__(self) -> Iterator[Str]: ...
    def filter(self, name: Literal['attributes', 'coros', 'data', 'defaults', 'hashs', 'inits', 'nodatas', 'pprops',
                                   'reprs', 'slots', 'states'],
               access: Access = ...) -> Optional[Union[dict, tuple]]: ...
    @classmethod
    def from_obj(cls, data: Any) -> Class: ...
    def state(self, obj: Any = None, access: Access = ...) -> TupleType: ...
    @classmethod
    def vars(cls, data: Any, access: Access = ..., both: bool = ..., ignore: Callable = ...,
             state: bool = ..., prop: bool = ...) -> DictStrAny: ...
class CmdError(Exception):
    def __init__(self, rv: subprocess.CompletedProcess) -> None: ...
class CmdAioError(CmdError):
    def __init__(self, rv: subprocess.CompletedProcess) -> None: ...
class DataClass(metaclass=abc.ABCMeta):
    __annotations__: DictStrAny
    __dataclass_fields__: dict[str, dataclasses.Field]
    def __repr__(self) -> str: ...
    @classmethod
    def __subclasshook__(cls, C: Type) -> bool: ...
class dd(typing.DefaultDict, MutableMapping[_KT, _VT], Generic[_KT, _VT]):
    __factory__: Optional[Callable]
    __slots__: TupleStr = ...
    @overload
    def __init__(self, *args: Any, **kwargs: Any) -> None: ...
    @overload
    def __init__(self, factory: typing.Callable = ..., *args: Any, **kwargs: Any) -> None: ...
    def __repr__(self) -> str: ...
    def __class_getitem__(cls, item: Any) -> GenericAlias: ...
class dictsort(dict, typing.MutableMapping[_KT, _VT], typing.Mapping[_KT, _VT], Generic[_KT, _VT]):
    __slots__: TupleStr = ...
    def __init__(self, *args: Any, **kwargs: Any) -> None: ...
    def sort(self) -> dictsort[_KT, _VT]: ...
class Executor(EnumBase, metaclass=EnumBaseMeta):
    PROCESS = ...
    THREAD = ...
    NONE = ...
    async def run(self, func: Any, *args: Any, **kwargs: Any) -> Any: ...
@typing.runtime_checkable
class GetItem(typing.Protocol):
    __slots__: TupleStr = ...
    @overload
    @abc.abstractmethod
    def __getitem__(self, i: int) -> _T_co: ...
    @overload
    @abc.abstractmethod
    def __getitem__(self, s: slice) -> Sequence[_T_co]: ...
@typing.runtime_checkable
class GetMethod(typing.Protocol):
    __slots__: TupleStr = ...
    @abc.abstractmethod
    def get(self, name: str, default: Any = ...) -> Any: ...
class getter(typing.Callable[[Any], Union[Any, typing.Tuple[Any, ...]]]):
    __slots__: TupleStr = ...
    _attrs: tuple
    _call: typing.Callable[[Any], Union[Any, typing.Tuple[Any, ...]]]
    _copy: bool
    _default: Any = ...
    _mm: bool
    @overload
    def __init__(self, name: Union[str, typing.Iterable[str]], default: Any = ...) -> None: ...
    @overload
    def __init__(self, *name: str, default: Any = ...) -> None: ...
    def __call__(self, obj: Any) -> Union[Any, tuple[Any, ...]]: ...
    def __repr__(self) -> str: ...
    def __reduce__(self)-> tuple[Type[getter], TupleStr]: ...
IntervalBase = NamedTuple('IntervalBase', begin=int, end=int, data=Union[ast.AST, AsyncsUnion, DefsUnion])
IntervalType: intervaltree.Interval[IntervalBase]
class Is(Generic[_T, _Is]):
    __slots__: TupleStr = ...
    _cls: TypesType
    _func: Optional[Callable]
    _iter: typing.Iterator[nstr]  #
    _mro: TupleType
    _mroitems: Dict[Union[Str, nstr], list]
    _type: Bool
    _varstype: Optional[Bool]
    data: Union[_T, inspect.FrameInfo, FrameType, typing.MutableMapping, TracebackType,
                       Any] = ...
    stack: int = ...
    def __init__(self, data: Any = ...) -> None: ...
    def __call__(self) -> TypesType: ...
    def __getstate__(self) -> DictStrAny: ...
    def __hash__(self) -> int: ...
    def __iter__(self) -> Iterator[Any]: ...
    def __reduce__(self) -> Tuple[Type[Is], Tuple]: ...
    def __repr__(self) -> Str: ...
    def __setstate__(self, state: DictStrAny): ...
    def __str__(self) -> Str: ...
    allattr: Bool
    annotationsattr: Bool
    asdictmethod: Bool
    asdictproperty: Bool
    ast: Bool
    asyncfor: Bool
    asyncfunctiondef: Bool
    asyncgen: Bool
    asyncgenfunction: Bool
    asyncs: Bool
    asyncwith: Bool
    await_ast: Bool
    awaitable: Bool
    bool: Bool
    builtin: Bool
    builtinclass: Bool
    builtinclassnodict: Bool
    builtinfunction: Bool
    builtinfunctiontype: Bool
    bytesio: Bool
    cached: bool
    cached_property: Bool
    callable: Bool
    chain: Bool
    chainmap: Bool
    classdef: Bool
    classvar: Bool
    classvar_or_initvar: Bool
    cls: TypesType
    clsmethod: Bool
    codetype: Bool
    collections: Bool
    container: Bool
    coro: Bool
    coroutine: Bool
    coroutinefunction: Bool
    dataclass: Bool
    datafield: Bool
    datamissing: Bool
    defaultdict: Bool
    defs: Bool
    deleter: Bool
    dict: Bool
    dynamicclassattribute: Bool
    dlst: Bool
    enum: Bool
    enum_sub: Bool
    enumbase: Bool
    enumbase_sub: Bool
    even: Union[Bool, NotImplemented]
    factory: Bool
    fileio: Bool
    float: Bool
    frameinfo: Bool
    frametype: Bool
    func: Optional[Callable]
    functiondef: Bool
    functiontype: Bool
    generator: Bool
    generatortype: Bool
    genericalias: Bool
    getitem: Bool
    getmethod: Bool
    getsetdescriptortype: Bool
    hashable: Bool
    import_ast: Bool
    importname: Str
    importfrom: Bool
    initvar: Bool
    installed: Union[Bool, NotImplemented]
    def instance(self, *args: Type) -> Bool: ...
    int: Bool
    io: Bool
    iterable: Bool
    iterator: Bool
    list_like: Bool
    lambda_ast: Bool
    lambdatype: Bool
    list: Bool
    lst: Bool
    mappingproxytype: Bool
    mappingproxytype_sub: Bool
    memberdescriptortype: Bool
    method: Bool
    methoddescriptor: Bool
    methoddescriptortype: Bool
    methodtype: Bool
    methodwrappertype: Bool
    methodwrappertype_sub: Bool
    missing: Bool
    missing_or_factory: Bool
    mlst: Bool
    mm: Bool
    moduletype: Bool
    namedtuple: Bool
    namedtupletyping: Bool
    noncomplex: Bool
    none: Bool
    object: Bool
    pathlib: Bool
    picklable: Bool
    primitive: Bool
    prop: Bool
    propany: Bool
    def readonly(self, name: Union[Str, nstr] = ...) -> Union[Bool, Exception]: ...
    reducible: Bool
    reducible_sequence_subclass: Bool
    routine: Bool
    sequence: Bool
    sequence_sub: Bool
    settype: Bool
    setter: Bool
    signature: Dict
    simple: Bool
    sized: Bool
    slotstype: Bool
    static: Bool
    str: Bool
    stringio: Bool
    def subclass(self, *args: Type) -> Bool: ...
    def supports(self, *args: Type) -> Bool: ...
    tracebacktype: Bool
    tuple: Bool
    type: Bool
    varstype: Bool
    wrapperdescriptortype: Bool
    def writeable(self, name: Union[Str, nstr]) -> Bool: ...
class MatchError(Exception):
    def __init__(self, *args, **kwargs) -> None: ...
class Missing:
    name: Final['MISSING']
    __slots__: TupleType = ...
    def __hash__(self) -> int: ...
    def __reduce__(self) -> tuple[Type[Missing], tuple]: ...
    def __repr__(self) -> str: ...
MISSING: Final[Missing()]
DictStrMissingAny = dict[str, Union[Missing, Any]]
class ModuleBase(EnumBase, metaclass=EnumBaseMeta):
    get: ModuleType = ...
    load: ModuleType = ...
class Module(ModuleBase):
    FUNCTOOLS = ...
    TYPING = ...
class nstr(str):
    name: str
    __slots__: TupleStr = ...
    def __new__(cls, value='', *args, **kwargs) -> nstr: ...
    def __init__(self, value='', *args, **kwargs) -> None: ...
    @overload
    def __call__(self, data: str = None) -> str: ...
    @overload
    def __call__(self, data: Any = None) -> bool: ...
    def get(self, obj: Any, default: Any = ...) -> Any: ...
    def getset(self, obj: Any, default: Any = ..., setvalue: bool = ...) -> Any: ...
    def has(self, obj: Any) -> bool: ...
    def hasget(self, obj: Any, default: Any = ...) -> Any: ...
    def hasgetany(self, obj: Any, default: Any = ...) -> Any: ...
    getter: getter
    def parse(self) -> NParser: ...
class _N(Generic[_T]):
    # Tuple - Attrs
    ABOUT: nstr = ...
    ABSTRACTMETHODS: nstr = ...
    AUTHOR: nstr = ...
    ADAPT: nstr = ...
    ALL: nstr = ...
    ALLOC: nstr = ...
    ANNOTATIONS: nstr = ...
    ARGS: nstr = ...
    ASDICT: nstr = ...
    ATTRIBUTES: nstr = ...
    BASE: nstr = ...
    BASICSIZE: nstr = ...
    BUILD_CLASS: nstr = ...
    BUILTINS: nstr = ...
    CACHE_CLEAR: nstr = ...
    CACHE_INFO: nstr = ...
    CACHED: nstr = ...
    CLASS: nstr = ...
    CODE: nstr = ...
    CONFORM: nstr = ...
    CONTAINS: nstr = ...
    CREDITS: nstr = ...
    COPY: nstr = ...
    COPYRIGHT: nstr = ...
    CVSID: nstr = ...
    DATACLASS_FIELDS: nstr = ...
    DATACLASS_PARAMS: nstr = ...
    DATE: nstr = ...
    DECIMAL_CONTEXT: nstr = ...
    DEEPCOPY: nstr = ...
    DELATTR: nstr = ...
    DICT: nstr = ...
    DICTOFFSET: nstr = ...
    DIR: nstr = ...
    DOC: nstr = ...
    DOCFORMAT: nstr = ...
    EMAIL: nstr = ...
    EQ: nstr = ...
    EXCEPTION: nstr = ...
    FILE: nstr = ...
    FLAGS: nstr = ...
    FUNC: nstr = ...
    GET: nstr = ...
    GETATTRIBUTE: nstr = ...
    GETFORMAT: nstr = ...
    GETINITARGS: nstr = ...
    GETITEM: nstr = ...
    GETNEWARGS: nstr = ...
    GETSTATE: nstr = ...
    HASH: nstr = ...
    HASH_EXCLUDE: nstr = ...
    IGNORE_ATTR: nstr = ...
    IGNORE_COPY: nstr = ...
    IGNORE_HASH: nstr = ...
    IGNORE_INIT: nstr = ...
    IGNORE_KWARG: nstr = ...
    IGNORE_REPR: nstr = ...
    IGNORE_STATE: nstr = ...
    IGNORE_STR: nstr = ...
    IMPORT: nstr = ...
    INIT: nstr = ...
    INIT_SUBCLASS: nstr = ...
    INITIALIZING: nstr = ...
    ISABSTRACTMETHOD: nstr = ...
    ITEMSIZE: nstr = ...
    LEN: nstr = ...
    LIBMPDEC_VERSION: nstr = ...
    LOADER: nstr = ...
    LTRACE: nstr = ...
    MAIN: nstr = ...
    MEMBERS: nstr = ...
    METHODS: nstr = ...
    MODULE: nstr = ...
    MP_MAIN: nstr = ...
    MRO: nstr = ...
    NAME: nstr = ...
    NEW: nstr = ...
    NEW_MEMBER: nstr = ...
    NEW_OBJ: nstr = ...
    NEW_OBJ_EX: nstr = ...
    OBJ_CLASS: nstr = ...
    OBJCLASS: nstr = ...
    PACKAGE: nstr = ...
    POST_INIT: nstr = ...
    PREPARE: nstr = ...
    QUALNAME: nstr = ...
    REDUCE: nstr = ...
    REDUCE_EX: nstr = ...
    REPR: nstr = ...
    REPR_EXCLUDE: nstr = ...
    REPR_NEWLINE: nstr = ...
    REPR_PPROPERTY: nstr = ...
    RETURN: nstr = ...
    SELF_CLASS: nstr = ...
    SETATTR: nstr = ...
    SETFORMAT: nstr = ...
    SETSTATE: nstr = ...
    SIGNATURE: nstr = ...
    SIZEOF: nstr = ...
    SLOTNAMES: nstr = ...
    SLOTS: nstr = ...
    SPEC: nstr = ...
    STATE: nstr = ...
    STATUS: nstr = ...
    STR: nstr = ...
    SUBCLASSHOOK: nstr = ...
    TEST: nstr = ...
    TEXT_SIGNATURE: nstr = ...
    THIS_CLASS: nstr = ...
    TRUNC: nstr = ...
    VERSION: nstr = ...
    WARNING_REGISTRY: nstr = ...
    WEAKREF: nstr = ...
    WEAKREFOFFSET: nstr = ...
    WRAPPED: nstr = ...
    _asdict: nstr = ...
    _cls: nstr = ...
    _copy: nstr = ...
    _count: nstr = ...
    _data: nstr = ...
    _extend: nstr = ...
    _external: nstr = ...
    _field_defaults: nstr = ...
    _field_type: nstr = ...
    _fields: nstr = ...
    _file: nstr = ...
    _filename: nstr = ...
    _frame: nstr = ...
    _func: nstr = ...
    _function: nstr = ...
    _get: nstr = ...
    _globals: nstr = ...
    _id: nstr = ...
    _index: nstr = ...
    _ip: nstr = ...
    _item: nstr = ...
    _items: nstr = ...
    _key: nstr = ...
    _keys: nstr = ...
    _kind: nstr = ...
    _locals: nstr = ...
    _name: nstr = ...
    _node: nstr = ...
    _origin: nstr = ...
    _obj: nstr = ...
    _object: nstr = ...
    _path: nstr = ...
    _repo: nstr = ...
    _RV: nstr = ...
    _rv: nstr = ...
    _pypi: nstr = ...
    _remove: nstr = ...
    _reverse: nstr = ...
    _sort: nstr = ...
    _source: nstr = ...
    _update: nstr = ...
    _value: nstr = ...
    _values: nstr = ...
    _vars: nstr = ...
    add: nstr = ...
    append: nstr = ...
    args: nstr = ...
    asdict: nstr = ...
    attr: nstr = ...
    attrs: nstr = ...
    authorized_keys: nstr = ...
    backup: nstr = ...
    cls: nstr = ...
    clear: nstr = ...
    cli: nstr = ...
    co_name: nstr = ...
    code_context: nstr = ...
    compare: nstr = ...
    copy: nstr = ...
    copyright: nstr = ...
    count: nstr = ...
    credits: nstr = ...
    data: nstr = ...
    default: nstr = ...
    default_factory: nstr = ...
    defaults: nstr = ...
    docs: nstr = ...
    endswith: nstr = ...
    exit: nstr = ...
    extend: nstr = ...
    external: nstr = ...
    f_back: nstr = ...
    f_code: nstr = ...
    f_globals: nstr = ...
    f_lineno: nstr = ...
    f_locals: nstr = ...
    file: nstr = ...
    filename: nstr = ...
    frame: nstr = ...
    func: nstr = ...
    function: nstr = ...
    get: nstr = ...
    globals: nstr = ...
    hash: nstr = ...
    help: nstr = ...
    id: nstr = ...
    id_rsa: nstr = ...
    ignore: nstr = ...
    index: nstr = ...
    init: nstr = ...
    ip: nstr = ...
    item: nstr = ...
    items: nstr = ...
    kali: nstr = ...
    key: nstr = ...
    keys: nstr = ...
    kind: nstr = ...
    kwarg: nstr = ...
    kwargs: nstr = ...
    kwargs_dict: nstr = ...
    license: nstr = ...
    lineno: nstr = ...
    locals: nstr = ...
    metadata: nstr = ...
    name: nstr = ...
    node: nstr = ...
    obj: nstr = ...
    object: nstr = ...
    origin: nstr = ...
    path: nstr = ...
    pop: nstr = ...
    popitem: nstr = ...
    public: nstr = ...
    pypi: nstr = ...
    PYPI: nstr = ...
    quit: nstr = ...
    remove: nstr = ...
    repo: nstr = ...
    REPO: nstr = ...
    repr: nstr = ...
    rv: nstr = ...
    reverse: nstr = ...
    scripts: nstr = ...
    search: nstr = ...
    self: nstr = ...
    sort: nstr = ...
    source: nstr = ...
    SOURCE: nstr = ...
    startswith: nstr = ...
    templates: nstr = ...
    test: nstr = ...
    tests: nstr = ...
    tb_frame: nstr = ...
    tb_lineno: nstr = ...
    tb_next: nstr = ...
    tmp: nstr = ...
    type: nstr = ...
    ubuntu: nstr = ...
    update: nstr = ...
    value: nstr = ...
    values: nstr = ...
    values_dict: nstr = ...
    vars: nstr = ...
    venv: nstr = ...
    # Dict 4 - Environment
    AMARILLO: str = ...
    ANSIBLE: str = ...
    ANSIBLE_SUDO_PASSWORD: str = ...
    APPLICATIONS: str = ...
    ATHENS_GONOSUM_PATTERNS: str = ...
    AZUL: str = ...
    AZULCLARO: str = ...
    BAPY: str = ...
    BASH_RC_DIR: str = ...
    BASH_RC_NAME: str = ...
    BASH_RC_PATH: str = ...
    BASH_RC_PROJECT: str = ...
    BREW: str = ...
    BREWFILE: str = ...
    CACHES: str = ...
    CLONES: str = ...
    CLT: str = ...
    CONFLUENCE_SERVER_PASS: str = ...
    DARWIN: str = ...
    DATA: str = ...
    DEBIAN: str = ...
    DEFAULT_CA_BUNDLE_PATH: str = ...
    DEFAULT_KALI_USER: str = ...
    DEVOPS_HOST: str = ...
    DEVOPS_SLD: str = ...
    DOCK: str = ...
    DOCKER_HOST: str = ...
    DOMAINED_DIR: str = ...
    DOMAINED_PATH: str = ...
    EDITOR: str = ...
    EXAMPLES: str = ...
    FILES: str = ...
    GEMFILE: str = ...
    GEOLOCATION_KEY: str = ...
    GITHUB_DESKTOP: str = ...
    GITHUB_DESKTOP_PROCESS: str = ...
    GITHUB_DOMAIN: str = ...
    GITHUB_EMAIL: str = ...
    GITHUB_ORGANIZATION: str = ...
    GITHUB_ORGANIZATION_CLONE_PREFIX_HTTP: str = ...
    GITHUB_ORGANIZATION_CLONE_PREFIX_SSH: str = ...
    GITHUB_ORGANIZATION_EMAIL: str = ...
    GITHUB_ORGANIZATION_ID: str = ...
    GITHUB_ORGANIZATION_ID_CLONE_PREFIX_SSH: str = ...
    GITHUB_ORGANIZATION_PASSWORD: str = ...
    GITHUB_ORGANIZATION_USERNAME: str = ...
    GITHUB_PRIVATE_URL: str = ...
    GITHUB_SECRETS_PATH: str = ...
    GITHUB_SECRETS_URL: str = ...
    GITHUB_URL: str = ...
    GITHUB_USERNAME: str = ...
    GIT_COMMAND: str = ...
    GIT_PREFIX: str = ...
    GIT_STORE: str = ...
    GO111MODULE: str = ...
    GOHOME: str = ...
    GOPATH: str = ...
    HOME: str = ...
    ICLOUD: str = ...
    ICLOUD_BASENAME: str = ...
    ICLOUD_NICK: str = ...
    INFOPATH: str = ...
    INTERNET: str = ...
    INTERNET_HASH: str = ...
    INVERSO: str = ...
    JETBRAINS: str = ...
    JETBRAINS_NAME: str = ...
    KALI: str = ...
    KEYNOTE: str = ...
    LANG: str = ...
    LATEST: str = ...
    LC_ALL: str = ...
    LIBRARY: str = ...
    LIBRARY_NICK: str = ...
    LOG: str = ...
    LOGNAME: str = ...
    LOG_BASENAME: str = ...
    MACDEV: str = ...
    MACDEV_BASENAME: str = ...
    MACDEV_NICK: str = ...
    MACKUP_ENGINE: str = ...
    MACROOT: str = ...
    MNOPI: str = ...
    MOBILE: str = ...
    MORADO: str = ...
    MSF_DATABASE_CONFIG: str = ...
    NPM: str = ...
    NPMFILE: str = ...
    NUMBERS: str = ...
    OPAMFILE: str = ...
    ORG: str = ...
    ORG_ATLAS_PASSWORD: str = ...
    ORG_BASENAME: str = ...
    ORG_GROUP_DEFAULT: str = ...
    ORG_HOST: str = ...
    ORG_SERVER: str = ...
    ORG_SLD: str = ...
    PACKAGES: str = ...
    PACKAGES_BASENAME: str = ...
    PAGES: str = ...
    PASSWD_PATH: str = ...
    PASSWORD: str = ...
    PATH: str = ...
    PEN: str = ...
    PEN_GIT: str = ...
    PEN_NICK: str = ...
    PREFS: str = ...
    PYCHARM: str = ...
    PYCHARM_NAME: str = ...
    PYCHARM_OPTIONS: str = ...
    PYCHARM_PLUGINS: str = ...
    PYCHARM_SCRATCHES: str = ...
    PYCHARM_VERSION: str = ...
    PYTHON39: str = ...
    PYTHON39_HOME: str = ...
    PYTHON39_PACKAGES: str = ...
    PYTHONASYNCIODEBUG: str = ...
    PYTHONDONTWRITEBYTECODE: str = ...
    PYTHONNOUSERSITE: str = ...
    PYTHONUNBUFFERED: str = ...
    REALNAME: str = ...
    REPO_DEFAULT_ADMIN_PASSWORD: str = ...
    REPO_DEFAULT_ADMIN_USERNAME: str = ...
    REPO_DEFAULT_API_URL: str = ...
    REPO_DEFAULT_API_VERSION: str = ...
    REPO_DEFAULT_HOST: str = ...
    REPO_DEFAULT_HOSTNAME: str = ...
    REPO_DEFAULT_PASSWORD: str = ...
    REPO_DEFAULT_SCHEME: str = ...
    REPO_DEFAULT_URL: str = ...
    REPO_DEFAULT_USERNAME: str = ...
    REQUESTS_CA_BUNDLE: str = ...
    REQUIREMENTS: str = ...
    ROJO: str = ...
    SAVED: str = ...
    SCALEWAY_ACCESS_KEY: str = ...
    SCALEWAY_ENDPOINT: str = ...
    SCALEWAY_ORGANIZATION_ID: str = ...
    SCALEWAY_SECRET_KEY: str = ...
    SCHEME: str = ...
    SCRATCHES: str = ...
    SCRATCHES_NAME: str = ...
    SCRIPTS: str = ...
    SCRIPTS_BASENAME: str = ...
    SCW_TOKEN: str = ...
    SECRETS_PATH: str = ...
    SECRETS_REPO: str = ...
    SERVERS: str = ...
    SERVERS_HOST: str = ...
    SERVERS_SLD: str = ...
    SHELL: str = ...
    SHELLCHECK_OPTS: str = ...
    SHLVL: str = ...
    SSH_AUTH_SOCK: str = ...
    SSH_PRIVATE_KEY: str = ...
    SSL_CERT_FILE: str = ...
    SUPPORT: str = ...
    SYNTHETIC: str = ...
    TERM: str = ...
    TERM_PROGRAM: str = ...
    TMPDIR: str = ...
    UBUNTU: str = ...
    USB: str = ...
    USER: str = ...
    USERFILE: str = ...
    USERHOME: str = ...
    USERNAME: str = ...
    VERDE: str = ...
    VIRTUAL_ENV: str = ...
    VISUAL: str = ...
    VULTR_API_KEY: str = ...
    VULTR_API_TIMEOUT: str = ...
    XPC_SERVICE_NAME: str = ...
    __slots__: TupleStr = ...
    @classmethod
    def _dict_(cls) -> dict[str, Union[nstr, Any]]: ...
    _dict_: dict[str, Union[nstr, Any]]
    def __repr__(self) -> str: ...
    @classmethod
    def BUILTIN_OTHER(cls) -> Tuple[nstr, ...]: ...
    @classmethod
    def MROITEMS(cls) -> dict[nstr, TupleStr]: ...
    @classmethod
    def SIGNATURES(cls) -> dict[nstr, nstr]: ...
    def __class_getitem__(cls, item: Any) -> Union[nstr, Any]: ...
N: Union[_N, type, Type[_N], Type] = ...
class NameAttr(metaclass=abc.ABCMeta):
    __slots__: TupleStr = ...
    name: str = ...
    @classmethod
    def __subclasshook__(cls, C: Type) -> bool: ...
class Namedtuple(metaclass=abc.ABCMeta):
    @classmethod
    def __subclasshook__(cls, C: Type) -> bool: ...
    @abc.abstractmethod
    def _asdict(self) -> DictStrAny: ...
    _fields: TupleStr
    _field_defaults: DictStrAny
class NamedTupleTyping(metaclass=abc.ABCMeta):
    __annotations__: DictStrAny
    _fields: TupleStr
    _field_defaults: DictStrAny
    def _asdict(self) -> DictStrAny: ...
    @classmethod
    def __subclasshook__(cls, C: Type) -> bool: ...
class NParser:
    data: str
    default: Any
    __slots__: TupleStr = ...
    def __init__(self, data: str = '', default: Any = None) -> None: ...
    def __repr__(self): ...
    def asdict(self): ...
    domain: Union[furl.furl, Any]
    email: Union[furl.furl, Any]
    environ: Union[furl.furl, str, IPv, int, pathlib.Path, Any]
    integer: Union[int, Any]
    ip: Union[IPv, Any]
    log_level: Union[str, Any]
    log_value: Union[int, Any]
    path: Union[pathlib.Path, Any]
    true: Union[bool, Any]
    url: Union[furl.furl, Any]
ObjBase = NamedTuple('ObjBase', c=Class, data=Any)
class Obj(ObjBase):
    cache: dict[tuple[TypesType, Callable], DictStrAny] = ...
    __slots__ = ()
    def __new__(cls, data: Any) -> Obj: ...
    def __iter__(self) -> Iterator[Str]: ...
    @property
    def deepcopy(self) -> Any: ...
    def hash(self, access: Access = ..., prop: bool = ...) -> DictStrAny: ...
    def init(self, access: Access = ...) -> DictStrAny: ...
    @property
    def pickles(self) -> Optional[bytes]: ...
    def repr(self, access: Access = ..., both: bool = ..., prop: bool = ...) -> DictStrAny: ...
    def state(self) -> DictStrAny: ...
    @property
    def state_methods(self) -> Any: ...
    @property
    def unpickles(self) -> Any: ...
    def vars(self, access: Access = ..., both: bool = ..., ignore: Callable = ...,
             state: bool = ..., prop: bool = ...) -> DictStrAny: ...
class PIs(EnumBase, metaclass=EnumBaseMeta):
    DIR = ...
    FILE = ...
class PMode(EnumBase, metaclass=EnumBaseMeta):
    DIR = ...
    FILE = ...
    X = ...
class POption(EnumBase, metaclass=EnumBaseMeta):
    BOTH = ...
    DIRS = ...
    FILES = ...
class POutput(EnumBase, metaclass=EnumBaseMeta):
    BOTH = ...
    BOX = ...
    DICT = ...
    LIST = ...
    NAMED = ...
    TUPLE = ...
class PSuffixBase(EnumBase, metaclass=EnumBaseMeta):
    def _generate_next_value_(self: Union[str, Callable[..., str]], *args) -> str: ...
class PSuffix(PSuffixBase):
    NO = ...
    BASH = ...
    ENV = ...
    GIT = ...
    INI = ...
    J2 = ...
    JINJA2 = ...
    LOG = ...
    MONGO = ...
    OUT = ...
    PY = ...
    RLOG = ...
    SH = ...
    SHELVE = ...
    SSH = ...
    TOML = ...
    YAML = ...
    YML = ...
class Path(pathlib.Path, pathlib.PurePosixPath, Generic[_Path], str):
    __slots__: TupleStr = ...
    _previous: Path
    _rv: Union[Path, FindUp, Any]
    endseparator: str
    find_packages: list
    installed: Path
    installedbin: Path
    installedpy: Path
    parents: Sequence[Path] = ...
    parent: Path = ...
    pwd: Path
    resolved: Path
    source: str
    stemfull: Path
    str: str
    text: str
    to_modname: Optional[str]
    to_module: Optional[Union[ModuleType, AllAttr]]
    def __new__(cls: Type[Path], *args: PathLikeStr, **kwargs: Any) -> Path: ...
    def __call__(self, name: Optional[str] = ..., file: bool = ...,
                 group: Optional[Union[str, int]] = ...,
                 mode: Optional[Union[int, str]] = ..., su: bool = ...,
                 u: Optional[Union[str, int]] = ...) -> Path: ...
    def __contains__(self, value: Iterable[str]) -> bool: ...
    def __eq__(self, other: Union[PathLikeStr, tuple[str]]) -> bool: ...
    def __hash__(self) -> int: ...
    def __lt__(self, other: PathLikeStr) -> bool: ...
    def __le__(self, other: PathLikeStr) -> bool: ...
    def __gt__(self, other: PathLikeStr) -> bool: ...
    def __ge__(self, other: PathLikeStr) -> bool: ...
    def __truediv__(self, key: PathLikeStr) -> Path: ...
    def __rtruediv__(self, key: PathLikeStr) -> Path: ...
    def _is_file(self) -> Optional[str]: ...
    def absolute(self) -> Path: ...
    def append_text(self, data, encoding=None, errors=None): ...
    def c_(self, p: Any = ...) -> Path: ...
    @property
    @contextlib.contextmanager
    def cd(self) -> Path: ...
    @classmethod
    def cwd(cls: Type[Path]) -> Path: ...
    def chdir(self): ...
    def chmod(self, mode: Optional[Union[int, str]] = ...) -> Path: ...
    def chown(self, group: Optional[Union[str, int]] = ...,
              u: Optional[Union[str, int]] = ...) -> Path: ...
    def expanduser(self) -> Path: ...
    def fd(self, flags: int, mode: int = ..., *, dir_fd: Optional[int] = ...) -> int: ...
    def find_up(self, file: PIs = ..., name: Union[str, PSuffix] = ..., uppermost: bool = ...) -> FindUp: ...
    @classmethod
    def from_obj(cls, obj: Any) -> Path: ...
    def glob(self, pattern: str) -> Generator[Path, None, None]: ...
    def has(self, value: str) -> bool: ...
    @classmethod
    def home(cls, name: str = ..., file: bool = ...) -> Path: ...
    @classmethod
    def internal(cls) -> PathInternal: ...
    def j2(self, dest: Any = ..., stream: bool = ..., variables: dict = ...) -> Union[list, dict]: ...
    def joinpath(self, *other: PathLikeStr) -> Path: ...
    def iterdir(self) -> tuple[Path, None, None]: ...
    def mkdir(self, name: Optional[str] = ..., group: Optional[Union[str, int]] = ...,
              mode: Optional[Union[int, str]] = ..., su: bool = ...,
              u: Optional[Union[str, int]] = ...) -> Path: ...
    def open(self, mode: str = ..., buffering: int = ..., encoding: str = ..., errors: str = ..., newline: str = ...,
             token: bool = ...) -> Optional[OpenIO]: ...
    def path(self, uppermost: bool = ...) -> Path: ...
    def read(self, encoding: Optional[str] = ..., errors: Optional[str] = ..., lnum: bool = False,
             token: bool = ...) -> Optional[Union[str, tuple[str, int]]]: ...
    def read_text(self, encoding: Optional[str] = ..., errors: Optional[str] = ...,
                  token: bool = ...) -> Optional[str]: ...
    def readlink(self) -> Path: ...
    def relative(self, p: Any) -> Path: ...
    def relative_to(self, *other: PathLikeStr) -> Path: ...
    def rename(self, target: PathLikeStr) -> Path: ...
    def replace(self, target: PathLikeStr) -> Path: ...
    def resolve(self, strict: bool = ...) -> Path: ...
    def rglob(self, pattern: str) -> typing.Generator[Path, None, None]: ...
    def rm(self, missing_ok=...): ...
    def root(self, uppermost=True): ...
    def rv(self, default: Any = ...) -> Union[Path, FindUp, Any]: ...
    def samefile(self, other_path: Union[str, bytes, int, Path]) -> bool: ...
    def scan(self, option: POption = ...,
             output: POutput = ..., suffix: PSuffix = ...,
             level: bool = ..., hidden: bool = ..., frozen: bool = ...) -> Union[dict, list]: ...
    @classmethod
    @overload
    def shelve(cls, path: PathLikeStr = ..., register: bool = ..., rm: bool = ...) -> DbfilenameShelf: ...
    @classmethod
    @overload
    def shelve(cls, path: PathLikeStr = ..., pathonly: bool = ...) -> Path: ...
    @classmethod
    @contextlib.contextmanager
    def shelvectx(cls, path: PathLikeStr = ..., rm: bool = ...) -> DbfilenameShelf: ...
    def symlink_to(self, target: Union[str, Path], target_is_directory: bool = ...) -> None: ...
    @classmethod
    def sys(cls) -> Path: ...
    def templates(self, stream: bool = ...) -> dict[str, Union[jinja2.Template.stream, jinja2.Template.render]]: ...
    @classmethod
    @contextlib.contextmanager
    def tmp(cls) -> Path: ...
    def to_modules(self, suffix: bool = ..., uppermost: bool = ...) -> str: ...
    @classmethod
    def to_parent(cls, path: PathLikeStr = ...) -> Path: ...
    def touch(self, name: Optional[str] = ..., group: Optional[Union[str, int]] = ...,
              mode: Optional[Union[int, str]] = ..., su: bool = ...,
              u: Optional[Union[str, int]] = ...) -> Path: ...
    def with_name(self, name: str) -> Path: ...
    def with_stem(self, stem: str) -> Path: ...
    def with_suffix(self, suffix: str) -> Path: ...
class PathGit(EnumBase, metaclass=EnumBaseMeta):
    PATH =  ...
    ORIGIN =  ...
    ORGANIZATION =  ...
    def cmd(self, path: PathLikeStr = ...) -> Optional[Union[Path, furl]]: ...
    @classmethod
    def top(cls, path: PathLikeStr = ...) -> GitTop: ...
class PathInstallScript(setuptools.command.install.install):
    def run(self): ...
    @classmethod
    def path(cls) -> str: ...
class Re(EnumBase, metaclass=EnumBaseMeta):
    ASYNCDEF = ...
    BLOCK = ...
    DEF = ...
    DECORATOR = ...
    ENVVAR = ...
    HEXSHA_ONLY = ...
    HEXSHA_SHORTENED = ...
    LAMBDA = ...
    LETTERS = ...
    LETTERS_NUMBERS = ...
    MODULE_IDENTIFIER = ...
    NUMBERS = ...
    TAB_FULL_LINE = ...
    UNDERSCORES_PREFIX = ...
    UNDERSCORES_SUFFIX = ...
    VAR = ...
    VAR_DASH = ...
    WHITESPACE = ...
    ALL = ...
    PRIVATE = ...
    PROTECTED = ...
    PUBLIC = ...
class ReposNamesBase:
    __slots__: TupleStr = ...
    name: str
    script: str
    def __init__(self, name: str = ..., script: str = ...) -> None: ...
    def __hash__(self) -> int: ...
    def __repr__(self) -> str: ...
    def __reduce__(self)-> tuple[Type[getter], TupleStr]: ...
class ReposNames(dict, typing.MutableMapping[_KT, ReposNamesBase], typing.Mapping[_KT, ReposNamesBase]):
    rccmd: ReposNamesBase
    rcdev: ReposNamesBase
    rclib: ReposNamesBase
    rctest: ReposNamesBase
    rcutils: ReposNamesBase
    rcvars: ReposNamesBase
    __slots__: TupleStr = ...
    def __init__(self) -> None: ...
    def __hash__(self) -> int: ...
    def __repr__(self) -> str: ...
    def __class_getitem__(cls, item: Any) -> GenericAlias: ...
class SlotsType(metaclass=abc.ABCMeta):
    __slots__: TupleStr = ...
    @classmethod
    def __subclasshook__(cls, C: Type) -> bool: ...
class SourceVars:
    file: Optional[Path]
    globs: DictStrAny
    locs: DictStrAny
    name: Optional[str]
    package: Optional[str]
    spec: ModuleSpec
    repo: Optional[str]
    pypi: Optional[str]
    source: Optional[Source]
    vars: DictStrAny
    __sourcevars__ = dict[str, str]
    __slots__: TupleStr
    def __init__(self, frame: FrameType = ...) -> None: ...
    def __eq__(self, other: SourceVars): ...
    def __getitem__(self, item: str) -> Any: ...
    def __getstate__(self) -> DictStrAny: ...
    def __repr__(self) -> str: ...
    def __setstate__(self, state: DictStrAny) -> SourceVars: ...
    @overload
    def get(self, item: str) -> Any: ...
    @overload
    def get(self, item: str, default: Type[None] = ...) -> Any: ...
SourceBase = NamedTuple('SourceBase', code=Optional[CodeType], data=Union[FrameType, Any], exists=bool,
                        file=Optional[Path], function=str, include=bool, internal=bool, lineno=int, module=bool,
                        node=Union[ast.AST, AsyncsUnion, DefsUnion], source=Union[str, list[str, int]],
                        vars=SourceVars)
class Source(SourceBase):
    EXCLUDE_DIRS: TupleStr = ...
    __slots__: TupleStr = ...
    def __new__(cls, data, **kwargs: Any) -> Source: ...
    def __class_getitem__(cls, item: Any) -> GenericAlias: ...
    args: DictStrAny = ...
class StateEnv(environs.Env, BaseState):
    def __init__(self, *, eager: bool = ..., expand_vars: bool = ...): ...
class UserActual:
    ROOT: bool = ...
    SUDO: bool = ...
    SUDO_USER: str = ...
    id: int = ...
    gecos: str = ...
    gid: int = ...
    gname: str = ...
    home: pathlib.Path = ...
    name: str = ...
    passwd: pwd.struct_passwd = ...
    shell: pathlib.Path = ...
    ssh: pathlib.Path = ...
    auth_keys: pathlib.Path = ...
    id_rsa: pathlib.Path = ...
    id_rsa_pub: pathlib.Path = ...
    git_config_path: pathlib.Path = ...
    def __init__(self) -> None: ...
class UserProcess:
    id: int = ...
    gecos: str = ...
    gid: int = ...
    gname: str = ...
    home: pathlib.Path = ...
    name: str = ...
    passwd: pwd.struct_passwd = ...
    ROOT: bool = ...
    shell: pathlib.Path = ...
    ssh: pathlib.Path = ...
    SUDO: bool = ...
    SUDO_USER: str = ...
    auth_keys: pathlib.Path = ...
    id_rsa: pathlib.Path = ...
    id_rsa_pub: pathlib.Path = ...
    git_config_path: pathlib.Path = ...
    git_config: git.GitConfigParser = ...
    github_username: str = ...
class User:
    actual: UserActual = ...
    process: UserProcess = ...
    gecos: str = ...
    gid: int = ...
    gname: str = ...
    home: pathlib.Path = ...
    id: int = ...
    name: str = ...
    passwd: pwd.struct_passwd = ...
    ROOT: bool = ...
    shell: pathlib.Path = ...
    ssh: pathlib.Path = ...
    SUDO: bool = ...
    SUDO_USER: str = ...
    auth_keys: pathlib.Path = ...
    id_rsa: pathlib.Path = ...
    id_rsa_pub: pathlib.Path = ...
    git_config_path: pathlib.Path = ...
    git_config: git.GitConfigParser = ...
    github_username: str = ...
    shelve: pathlib.Path = ...
    GIT_SSH_COMMAND: str = ...
    def __contains__(self, item: Union[User, str]) -> bool: ...
    def __eq__(self, other: User) -> bool: ...
    def __hash__(self) -> int: ...
    @staticmethod
    def sudo(command, su: bool = ...) -> str: ...
class VarsType(metaclass=abc.ABCMeta):
    __dict__: DictStrAny
    @classmethod
    def __subclasshook__(cls, C: Type) -> bool: ...

# Dependant
FindUp = NamedTuple('FindUp', path=Optional[Path], previous=Optional[Path])
class Frame(Generic[_T]):
    cache: dict[Path, Frame]
    # Coro = NamedTuple('Coro', func=bool, line=bool, value=bool)
    class Coro(TypedDict):
        func: bool
        line: bool
    class Line(TypedDict):
        coro: Frame.Coro
        nodes: list[typing.Union[ast.AST, AsyncsUnion, DefsUnion]]
        source: str
    _args: Optional[DictStrAny]
    args: DictStrAny
    cls: Optional[str]
    code: CodeType
    context: Optional[list[str, ...]]
    coro: bool
    decorator: list[str, ...]
    external: bool
    file: Path
    frame: FrameType
    function: str
    functions: intervaltree.IntervalTree
    include: bool
    internal: bool
    lineno: int
    lines: dict[int, Line]
    module: bool
    node: Union[ast.AST, AsyncsUnion, DefsUnion, ast.stmt, ast.Import, ast.ImportFrom]
    real: Optional[int]
    qualname: Optional[str]
    source: Optional[str]
    _vars: Optional[SourceVars]
    vars: SourceVars
    __slots__: TupleStr = ...
    def __init__(self, frame: FrameType) -> None: ...
    def __add__(self, node: Union[ast.AST, AsyncsUnion, DefsUnion, ast.stmt]) -> Optional[bool]: ...
    def __hash__(self) -> int: ...
    def __iter__(self) -> Iterator[Union[ast.AST, AsyncsUnion, DefsUnion, ast.stmt, ast.Import, ast.ImportFrom]]: ...
    def __reduce__(self) -> Tuple[Type[Is], Tuple]: ...
    def __repr__(self) -> Str: ...
    def __class_getitem__(cls, item: Any) -> GenericAlias: ...
FrameIdBase = NamedTuple('FrameIdBase', code=str, decorator=Union[list, str], function=str, parts=Union[list, str],
                         real=Optional[int], coro=bool)
class FrameId(EnumBase, metaclass=EnumBaseMeta):
    ASYNCCONTEXTMANAGER = ...
    IMPORTLIB = ...
    RUN = ...
    TO_THREAD = ...
    # FUNCDISPATCH = ('return funcs[Call().ASYNC]', 'wrapper bapy', 'core', 1)
FrameSimple = NamedTuple('FrameSimple', back=FrameType, code=CodeType,
                         frame=FrameType, function=str,
                         globals=DictStrAny, lineno=int, locals=DictStrAny, name=str,
                         package=str, path=Path, vars=DictStrAny)
GitTop = NamedTuple('GitTop', name=str, origin=furl, path=Path)
PathLikeStr = Union[os.PathLike, Path, str]
PathInternal = NamedTuple('PathInternal', file=Path, path=Path, package=str)
path_internal: PathInternal
SYSCONFIG_PATHS_EXCLUDE: tuple[Path, ...]
PATHS_EXCL: tuple[Path]
Real = NamedTuple('Real', caller=Frame, real=Optional[Frame])
class Stack(tuple[Frame]):
    real: Optional[Frame]
    def __new__(cls, init: bool = ...) -> Stack[Frame]: ...
    def __call__(self, index: int = ..., real: bool = ...) -> Union[Frame, Real]: ...
    def __repr__(self) -> str: ...
    @classmethod
    def init(cls) -> Stack[Frame]: ...
    @classmethod
    def main(cls) -> Frame: ...
    @classmethod
    def package(cls) -> Frame: ...
Types = Union[AllAttr, AnnotationsAttr, AsDictMethod, AsDictProperty, DataClass,
                     GetItem, GetMethod,
                     NameAttr, Namedtuple, NamedTupleTyping, VarsType, SlotsType]
TypesType = Union[Type[Any], Type[AllAttr], Type[AnnotationsAttr],
                         Type[AsDictMethod], Type[AsDictProperty],
                         Type[DataClass],
                         Type[GetItem], Type[GetMethod],
                         Type[NameAttr], Type[Namedtuple], Type[NamedTupleTyping],
                         Type[VarsType], Type[SlotsType]]
# Echo
def black(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
          blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def blue(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
         blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def cyan(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
         blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def green(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
          blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def magenta(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
            blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def red(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
        blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def white(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
          blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def yellow(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
           blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def bblack(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
           blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def bblue(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
          blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def bcyan(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
          blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def bgreen(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
           blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def bmagenta(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
             blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def bred(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
         blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def bwhite(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
           blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
def byellow(msg: Any, bold: bool = ..., nl: bool = ..., underline: bool = ...,
            blink: bool = ..., err: bool = ..., reset: bool = ..., rc: Optional[int] = ...) -> None: ...
# Instances
alocks: dd[Union[typing.Hashable, Path, str], asyncio.Lock] = ...
locks: dd[Union[typing.Hashable, Path, str], LockClass] = ...
reposnames: ReposNames = ...
user: User = ...
init_stack: list[inspect.FrameInfo]
